@@ -10,7 +10,7 @@ use File::HomeDir;
 use Log::Any qw/$log/;
 use Path::Tiny qw/path rootdir cwd/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 our $pager;
 
 sub DBVERSION { 1 }
@@ -759,10 +759,10 @@ sub get_change {
     return $data;
 }
 
-sub get_topic {
+sub get_node {
     my $self = shift;
 
-    my $token = shift // Carp::confess('get_topic needs defined');
+    my $token = shift // Carp::confess('get_node needs defined');
     my $kind  = shift;
     my $db    = $self->db;
 
@@ -771,16 +771,16 @@ sub get_topic {
     if ( $token =~ m/^\d+$/ ) {
         my $data = $db->xhashref(
             select => [
-                't.id AS id',
-                't.kind AS kind',
-                't.uuid AS uuid',
-                't.first_change_id AS first_change_id',
+                'n.id AS id',
+                'n.kind AS kind',
+                'n.uuid AS uuid',
+                'n.first_change_id AS first_change_id',
             ],
-            from  => 'topics t',
-            where => { 't.id' => $token },
+            from  => 'nodes n',
+            where => { 'n.id' => $token },
         );
 
-        return $self->err( 'WrongKind', 'topic (%s) is not a %s: %d',
+        return $self->err( 'WrongKind', 'node (%s) is not a %s: %d',
             $data->{kind}, $kind, $token )
           if $data && $kind && $kind ne $data->{kind};
 
@@ -791,7 +791,7 @@ sub get_topic {
     die $@ if ( $@ && $@->isa('Bif::Error::AmbiguousPath') );
     return $pinfo if $pinfo;
 
-    $kind ||= 'topic';
+    $kind ||= 'node';
     return $self->err( 'TopicNotFound', "$kind not found: $token" );
 }
 
@@ -799,15 +799,15 @@ sub current_work {
     my $self = shift;
     return $self->dbw->xhashref(
         select => [
-            't.id AS topic_id',
-            't.kind AS kind',
-            't.path AS path',
+            'n.id AS node_id',
+            'n.kind AS kind',
+            'n.path AS path',
             'wb.start AS start',
             'wb.billable AS billable',
         ],
         from       => 'work_buffers wb',
-        inner_join => 'topics t',
-        on         => 't.id = wb.topic_id',
+        inner_join => 'nodes n',
+        on         => 'n.id = wb.node_id',
         where      => { 'wb.stop' => undef },
     );
 }
@@ -833,7 +833,7 @@ sub start_work {
     return $self->dbw->xdo(
         insert_into => 'work_buffers',
         values      => {
-            topic_id      => $args->{topic_id},
+            node_id       => $args->{node_id},
             start         => $args->{start},
             start_comment => $args->{start_comment},
             stop          => $args->{stop},
@@ -888,7 +888,7 @@ sub stop_work {
             $self->dbw->xdo(
                 insert_into => 'work_buffers',
                 values      => {
-                    topic_id      => $ref->{topic_id},
+                    node_id       => $ref->{node_id},
                     start         => ( $boundary - $ref->{offset} + 1 )->epoch,
                     start_comment => $ref->{start_comment},
                     stop          => undef,
@@ -913,7 +913,7 @@ sub stop_work {
     if ( $args->{restore} and my $saved = $self->work_buffer ) {
 
         $self->start_work(
-            topic_id      => $saved->{topic_id},
+            node_id       => $saved->{node_id},
             offset        => $saved->{offset},
             start         => $args->{stop},
             start_comment => $saved->{start_comment},
@@ -930,18 +930,18 @@ sub save_work {
 
     $self->dbw->xdo(
         insert_into => [
-            'func_new_work', qw/change_id topic_id offset start stop
+            'func_new_work', qw/change_id node_id offset start stop
               start_comment stop_comment/
         ],
         select => [
-            $args->{change_id}, $args->{topic_id},
+            $args->{change_id}, $args->{node_id},
             'wb.offset',        'wb.start',
             'wb.stop',          'wb.start_comment',
             'wb.stop_comment',
         ],
         from  => 'work_buffers wb',
         where => {
-            'wb.topic_id' => $args->{topic_id},
+            'wb.node_id'  => $args->{node_id},
             'wb.billable' => 1,
             'wb.stop !'   => undef,
         },
@@ -950,7 +950,7 @@ sub save_work {
     $self->dbw->xdo(
         delete_from => 'work_buffers',
         where       => {
-            'topic_id' => $args->{topic_id},
+            'node_id'  => $args->{node_id},
             'billable' => 1,
             'stop !'   => undef,
         }
@@ -1138,7 +1138,7 @@ App::bif - A base class for App::bif::* commands
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -1318,7 +1318,7 @@ to the actual command. Needs to be documented .... sorry.
 
 =item user_id -> Int
 
-Returns the topic ID for the user (self) identity.
+Returns the node ID for the user (self) identity.
 
 =item uuid2id( $try ) -> Int
 
@@ -1334,8 +1334,8 @@ string of the form C<PROJECT[@HUB]>.
 
 =item get_hub( $name ) -> HashRef
 
-Looks up the hub where $name is either the topic ID, the hub name, or a
-hub location and returns the equivalent of C<get_topic($ID)> plus the
+Looks up the hub where $name is either the node ID, the hub name, or a
+hub location and returns the equivalent of C<get_node($ID)> plus the
 hub name.
 
 =item render_table( $format, \@header, \@data, [ $indent ] ) -> Str
@@ -1376,20 +1376,20 @@ C<$first_change_id> is provided then a check will be made to ensure
 that that C<$CID> is a child of <$first_change_id> with a
 FirstChangeMismatch error thrown if that is not the case.
 
-=item get_topic( $TOKEN ) -> HashRef
+=item get_node( $TOKEN ) -> HashRef
 
-Looks up the topic identified by C<$TOKEN> and returns undef or a hash
+Looks up the node identified by C<$TOKEN> and returns undef or a hash
 reference containg the following keys:
 
 =over
 
-=item * id - the topic ID
+=item * id - the node ID
 
-=item * first_change_id - the change_id that created the topic
+=item * first_change_id - the change_id that created the node
 
-=item * kind - the type of the topic
+=item * kind - the type of the node
 
-=item * uuid - the universally unique identifier of the topic
+=item * uuid - the universally unique identifier of the node
 
 =back
 
@@ -1399,7 +1399,7 @@ Returns a hashref representing the currently open work buffer:
 
 =over
 
-=item * topic_id
+=item * node_id
 
 =item * kind
 
@@ -1417,7 +1417,7 @@ Creates a new entry in the work_buffers table.
 
 =over
 
-=item * topic_id
+=item * node_id
 
 =item * start
 
