@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sq/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -34,12 +34,12 @@ sub run {
                 where       => { id => $info->{id} },
             );
 
-            print "Hub dropped: $info->{name} <$uuid>\n",
+            print "Hub dropped: $info->{name} <$uuid>\n";
 
-              $self->stop_work(
+            $self->stop_work(
                 stop    => time,
                 restore => 1,
-              );
+            );
         }
     );
 
@@ -57,7 +57,7 @@ bif-drop-hub - remove an hub from the repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
