@@ -3,14 +3,14 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
-    my $info = $self->get_topic( $opts->{id}, 'task' );
+    my $info = $self->get_node( $opts->{id}, 'task' );
 
     if ( !$opts->{force} ) {
         print "Nothing dropped (missing --force, -f)\n";
@@ -29,7 +29,7 @@ sub run {
             );
 
             # TODO: copy existing work_deltas rows into work_buffers
-            # with NULL topic_id so that the work activity is not lost.
+            # with NULL node_id so that the work activity is not lost.
             # Perhaps a new --no-work-buffer option or similar to
             # disable that behaviour.
             $dbw->xdo(
@@ -60,7 +60,7 @@ bif-drop-task - remove an task from the repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
