@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Path::Tiny qw/cwd path/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub init_user_repo {
@@ -115,7 +115,7 @@ bif-init - initialize a new bif repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -248,7 +248,7 @@ You can initialize a remote hub by specifying the provider's host as
 the LOCATION.
 
     bif list hosts
-    bif init myhub host.provider
+    bif init myhub hosn.provider
 
 =head1 ARGUMENTS & OPTIONS
 
