@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Term::ANSIColor 'color';
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -18,7 +18,7 @@ sub run {
 
     my $data = $db->xarrayrefs(
         select => [
-            concat( qv($dark), 't.kind', qv($reset) )->as('type'),
+            concat( qv($dark), 'n.kind', qv($reset) )->as('type'),
             'e.id', 'e.name',
             "ecm.mvalue || ' (' || ecm.method || ')' AS contact",
             case (
@@ -28,8 +28,8 @@ sub run {
             )->as('via'),
         ],
         from       => 'entities e',
-        inner_join => 'topics t',
-        on         => 't.id = e.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = e.id',
         inner_join => 'entities c',
         on         => 'c.id = e.contact_id',
         inner_join => 'entity_contact_methods ecm',
@@ -58,7 +58,7 @@ bif-list-entities - list entities present in repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
