@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use Term::ANSIColor qw/color/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -15,11 +15,11 @@ sub run {
     DBIx::ThinSQL->import(qw/ qv concat/);
 
     my $data = $db->xarrayrefs(
-        select     => [ 't.kind', 'h.id', 't.path', 'h.location', ],
+        select     => [ 'n.kind', 'h.id', 'n.path', 'h.location', ],
         from       => 'hubs h',
-        inner_join => 'topics t',
-        on         => 't.id = h.id',
-        order_by => [ 't.path', 'h.location' ],
+        inner_join => 'nodes n',
+        on         => 'n.id = h.id',
+        order_by => [ 'n.path', 'h.location' ],
     );
 
     return $self->ok('ListHubs') unless $data;
@@ -43,7 +43,7 @@ bif-list-hubs - list hubs registered with current repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
