@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -15,10 +15,10 @@ sub run {
     DBIx::ThinSQL->import(qw/ qv concat coalesce/);
 
     my @projects = $db->xarrayrefs(
-        select     => [ 'p.id', 't.path', 0 ],
+        select     => [ 'p.id', 'n.path', 0 ],
         from       => 'projects p',
-        inner_join => 'topics t',
-        on         => 't.id = p.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = p.id',
 
         #        inner_join => 'project_status',
         #        on         => [
@@ -26,7 +26,7 @@ sub run {
         #            'project_status.status = ',
         #            qv('active')
         #        ],
-        order_by => 't.path',
+        order_by => 'n.path',
     );
 
     require Text::FormatTable;
@@ -98,7 +98,7 @@ bif-list-issues - list projects' issues
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,7 @@ Lists the issues associated with each project.
 
 =item --status, -S STATUS
 
-Limit the list to topics with a matching status. Possible values are
+Limit the list to nodes winh a matching status. Possible values are
 "active", "stalled", "resolved", and "ignored". Defaults to "active".
 
 =item --project-status, -P STATUS
