@@ -11,7 +11,7 @@ use Time::Duration qw/ago/;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -19,7 +19,7 @@ sub run {
     my $opts = $self->opts;
 
     if ( $opts->{id} ) {
-        my $info  = $self->get_topic( $opts->{id} );
+        my $info  = $self->get_node( $opts->{id} );
         my $class = "App::bif::log::$info->{kind}";
 
         if ( eval "require $class" ) {
@@ -72,7 +72,7 @@ sub run_by_full {
         ),
         select => [
             '"c" || c.id AS change_id',
-            't.path AS path',
+            'n.path AS path',
             'COALESCE(c.author,e.name) AS author',
             "COALESCE(c.author_contact_method || ': ' || c.author_contact,"
               . "ecm.method || ': ' || ecm.mvalue) AS contact",
@@ -93,7 +93,7 @@ sub run_by_full {
                     else => qv(''),
                 ),
                 qv(' '),
-                't.path'
+                'n.path'
 
             )->as('action'),
         ],
@@ -109,17 +109,15 @@ sub run_by_full {
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
         left_join  => 'tasks ta',
-        on         => 'ta.id = cd.action_topic_id_1',
+        on         => 'ta.id = cd.action_node_id_1',
         left_join  => 'task_status ts',
         on         => 'ts.id = ta.task_status_id',
         left_join  => 'issues iss',
-        on         => 'iss.id = cd.action_topic_id_1',
-        left_join  => 'topics tp',
-        on         => 'tp.id = ta.id',
+        on         => 'iss.id = cd.action_node_id_1',
         left_join  => 'projects p',
-        on         => 'p.id = ts.project_id OR p.id = cd.action_topic_id_1',
-        left_join  => 'topics t',
-        on         => 't.id = c.action_topic_id_1',
+        on         => 'p.id = ts.project_id OR p.id = cd.action_node_id_1',
+        left_join  => 'nodes n',
+        on         => 'n.id = c.action_node_id_1',
         order_by   => \@order,
     );
 
@@ -181,7 +179,7 @@ sub run_by_time {
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
         left_join  => 'tasks t',
-        on         => 't.id = cd.action_topic_id_1',
+        on         => 't.id = cd.action_node_id_1',
         left_join  => 'task_status ts',
         on         => 'ts.id = t.task_status_id',
         order_by   => [ 'mdate DESC', 'c.mtime ASC', 'c.id DESC' ],
@@ -282,11 +280,11 @@ sub run_by_id {
         left_join  => 'b',
         on         => 'c.id BETWEEN b.start+1 AND b.stop',
         left_join  => 'tasks t',
-        on         => 't.id = cd.action_topic_id_1',
+        on         => 't.id = cd.action_node_id_1',
         left_join  => 'task_status ts',
         on         => 'ts.id = t.task_status_id',
         left_join  => 'projects p',
-        on         => 'p.id = ts.project_id OR p.id = cd.action_topic_id_1',
+        on         => 'p.id = ts.project_id OR p.id = cd.action_node_id_1',
         order_by   => ['c.id DESC'],
     );
 
@@ -496,11 +494,11 @@ __END__
 
 =for bif-doc #history
 
-bif-log - review the repository or topic history
+bif-log - review the repository or node history
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -519,9 +517,8 @@ chronological order.
 
 =item ITEM
 
-A topic kind. As a shortcut, if ITEM is a topic ID or a project PATH
-then the ITEM kind will be looked up and the appropriate sub-command
-run.
+A node kind. As a shortcut, if ITEM is a node ID or a project PATH then
+the ITEM kind will be looked up and the appropriate sub-command run.
 
 =item --action, -a
 
