@@ -4,14 +4,14 @@ use warnings;
 use locale;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::log';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_topic( $opts->{id}, 'identity' );
+    my $info = $self->get_node( $opts->{id}, 'identity' );
     my $now  = $self->now;
 
     DBIx::ThinSQL->import(qw/concat case func qv/);
@@ -74,9 +74,9 @@ sub run {
                 else => qv('*unknown*'),
             )->as('delta_value'),
         ],
-        from       => 'topics t',
+        from       => 'nodes n',
         inner_join => 'changes_tree ct',
-        on         => 'ct.parent = t.first_change_id',
+        on         => 'ct.parent = n.first_change_id',
         inner_join => 'changes c',
         on         => 'c.id = ct.child',
         inner_join => 'entities i',
@@ -93,7 +93,7 @@ sub run {
         on         => 'ecmd.id = d.id',
         left_join  => 'entity_contact_methods ecm2',
         on         => 'ecm2.id = ed.default_contact_method_id',
-        where      => { 't.id' => $info->{id} },
+        where      => { 'n.id' => $info->{id} },
         order_by   => 'c.path,d.id',
     );
 
@@ -119,7 +119,7 @@ bif-log-identity - review the history of a identity
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
