@@ -4,14 +4,14 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::log';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_topic( $opts->{id}, 'issue' );
+    my $info = $self->get_node( $opts->{id}, 'issue' );
 
     state $have_dbix = DBIx::ThinSQL->import(qw/ qv concat /);
     my $now = $self->now;
@@ -83,7 +83,7 @@ bif-log-issue - review the history of a issue
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
