@@ -4,7 +4,7 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::log';
 
 sub run {
@@ -19,7 +19,7 @@ sub run {
     my $sth = $db->xprepare(
         select => [
             'project_deltas.project_id AS id',
-            'SUBSTR(t.uuid,1,8) AS uuid',
+            'SUBSTR(n.uuid,1,8) AS uuid',
             concat( qv('c'), 'changes.id' )->as('change_id'),
             'SUBSTR(changes.uuid,1,8) AS change_uuid',
             'project_deltas.title',
@@ -34,18 +34,18 @@ sub run {
             'changes_tree.depth',
             'project_status.status',
             'project_status.status',
-            't.path',
-            'td.name',
+            'n.path',
+            'nd.name',
         ],
         from       => 'project_deltas',
-        inner_join => 'topic_deltas td',
-        on         => 'td.id = project_deltas.id',
+        inner_join => 'node_deltas nd',
+        on         => 'nd.id = project_deltas.id',
         inner_join => 'projects',
         on         => 'projects.id = project_deltas.project_id',
-        inner_join => 'topics t',
-        on         => 't.id = projects.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = projects.id',
         inner_join => 'changes_tree',
-        on         => 'changes_tree.parent = t.first_change_id AND
+        on         => 'changes_tree.parent = n.first_change_id AND
                        changes_tree.child = project_deltas.change_id',
         inner_join => 'changes',
         on         => 'changes.id = changes_tree.child',
@@ -88,7 +88,7 @@ bif-log-project - review a project history
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
