@@ -4,14 +4,14 @@ use warnings;
 use feature 'state';
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::log';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $db   = $self->db;
-    my $info = $self->get_topic( $opts->{id}, 'task' );
+    my $info = $self->get_node( $opts->{id}, 'task' );
 
     state $have_dbix = DBIx::ThinSQL->import(qw/ qv concat coalesce/);
     my $now = $self->now;
@@ -19,7 +19,7 @@ sub run {
     my $sth = $db->xprepare(
         select => [
             'task_deltas.task_id AS id',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
             concat( qv('c'), 'task_deltas.change_id' )->as('change_id'),
             'changes.uuid AS change_uuid',
             'task_deltas.title',
@@ -45,8 +45,8 @@ sub run {
         on         => 'e.id = changes.identity_id',
         inner_join => 'entity_contact_methods ecm',
         on         => 'ecm.id = e.default_contact_method_id',
-        inner_join => 'topics t',
-        on         => 't.id = task_deltas.task_id',
+        inner_join => 'nodes n',
+        on         => 'n.id = task_deltas.task_id',
         left_join  => 'task_status',
         on         => 'task_status.id = task_deltas.task_status_id',
         left_join  => 'projects',
@@ -89,7 +89,7 @@ bif-log-task - review a task history
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
