@@ -7,7 +7,7 @@ use DBIx::ThinSQL qw/bv/;
 use IO::Prompt::Tiny qw/prompt/;
 use Path::Tiny qw/path/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -59,8 +59,8 @@ sub run {
               || return $self->err( 'ValueRequired', 'value is required' );
 
             $opts->{message} ||= '';
-            $opts->{id}     = $dbw->nextval('topics');
-            $opts->{ecm_id} = $dbw->nextval('topics');
+            $opts->{id}     = $dbw->nextval('nodes');
+            $opts->{ecm_id} = $dbw->nextval('nodes');
 
             if ( $opts->{self} ) {
                 $opts->{change_id} = $self->new_change(
@@ -107,7 +107,7 @@ sub run {
             );
 
             $self->start_work(
-                topic_id      => $opts->{id},
+                node_id       => $opts->{id},
                 start         => $start,
                 start_comment => "new identity",
                 billable      => 1,
@@ -119,7 +119,7 @@ sub run {
             );
 
             $self->save_work(
-                topic_id  => $opts->{id},
+                node_id   => $opts->{id},
                 change_id => $opts->{change_id}
             );
 
@@ -128,7 +128,7 @@ sub run {
                 message       => $opts->{message},
                 action_format => "new identity %s "
                   . "$opts->{name} ($opts->{shortname})",
-                action_topic_id_1 => $opts->{id},
+                action_node_id_1 => $opts->{id},
             );
         }
     );
@@ -147,7 +147,7 @@ bif-new-identity - create a new identity in the repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
