@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -26,12 +26,12 @@ sub run {
             if ( !$opts->{path} ) {
 
                 my @paths = $dbw->xarrayrefs(
-                    select     => 't.path',
+                    select     => 'n.path',
                     from       => 'projects p',
-                    inner_join => 'topics t',
-                    on         => 't.id = p.id',
+                    inner_join => 'nodes n',
+                    on         => 'n.id = p.id',
                     order_by =>
-                      [ 't.kind = "project" DESC', 'p.local DESC', 't.path', ],
+                      [ 'n.kind = "project" DESC', 'p.local DESC', 'n.path', ],
                 );
 
                 if ( 0 == @paths ) {
@@ -85,7 +85,7 @@ sub run {
 #   - What (output) actually occured?
 #"
             );
-            $opts->{id}        = $dbw->nextval('topics');
+            $opts->{id}        = $dbw->nextval('nodes');
             $opts->{change_id} = $self->new_change;
 
             $dbw->xdo(
@@ -99,7 +99,7 @@ sub run {
             );
 
             $self->start_work(
-                topic_id      => $opts->{id},
+                node_id       => $opts->{id},
                 start         => $start,
                 start_comment => "new issue",
                 billable      => 1,
@@ -111,15 +111,15 @@ sub run {
             );
 
             $self->save_work(
-                topic_id  => $opts->{id},
+                node_id   => $opts->{id},
                 change_id => $opts->{change_id}
             );
 
             $self->end_change(
-                id                => $opts->{change_id},
-                action_format     => "new issue %s",
-                action_topic_id_1 => $opts->{id},
-                message           => $opts->{message},
+                id               => $opts->{change_id},
+                action_format    => "new issue %s",
+                action_node_id_1 => $opts->{id},
+                message          => $opts->{message},
             );
 
         }
@@ -139,7 +139,7 @@ bif-new-issue - add a new issue to a project
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
