@@ -5,7 +5,7 @@ use Bif::Mo;
 use IO::Prompt::Tiny qw/prompt/;
 use DBIx::ThinSQL qw/ qv sq/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub dup {
@@ -23,10 +23,10 @@ sub dup {
     );
 
     my $src = $dbw->xval(
-        select     => 't.path',
+        select     => 'n.path',
         from       => 'projects p',
-        inner_join => 'topics t',
-        on         => 't.id = p.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = p.id',
         where      => { 'p.id' => $dup_pinfo->{id} },
     );
 
@@ -35,7 +35,7 @@ sub dup {
 
     $dbw->txn(
         sub {
-            $opts->{id} ||= $dbw->nextval('topics');
+            $opts->{id} ||= $dbw->nextval('nodes');
             $opts->{change_id} ||= $self->new_change;
 
             $dbw->xdo(
@@ -78,7 +78,7 @@ sub dup {
 
             my $status_id;
             foreach my $status (@status) {
-                my $sid = $dbw->nextval('topics');
+                my $sid = $dbw->nextval('nodes');
                 $status_id = $sid if $status->{current_id};
 
                 $dbw->xdo(
@@ -110,7 +110,7 @@ sub dup {
             );
 
             foreach my $status (@status) {
-                my $sid = $dbw->nextval('topics');
+                my $sid = $dbw->nextval('nodes');
 
                 $dbw->xdo(
                     insert_into => 'func_new_issue_status',
@@ -133,7 +133,7 @@ sub dup {
             );
 
             foreach my $status (@status) {
-                my $sid = $dbw->nextval('topics');
+                my $sid = $dbw->nextval('nodes');
 
                 $dbw->xdo(
                     insert_into => 'func_new_task_status',
@@ -152,9 +152,9 @@ sub dup {
                 id => $opts->{change_id},
                 action_format =>
 "new project $opts->{path} (%s) --dup $dup_pinfo->{path} (%s)]",
-                action_topic_id_1 => $opts->{id},
-                action_topic_id_1 => $dup_pinfo->{id},
-                message           => $opts->{message},
+                action_node_id_1 => $opts->{id},
+                action_node_id_1 => $dup_pinfo->{id},
+                message          => $opts->{message},
             );
 
         }
@@ -196,7 +196,7 @@ sub new_project {
     );
 
     foreach my $status (@status) {
-        my $sid = $dbw->nextval('topics');
+        my $sid = $dbw->nextval('nodes');
 
         $dbw->xdo(
             insert_into => 'func_new_project_status',
@@ -246,7 +246,7 @@ sub new_project {
     );
 
     foreach my $status (@status) {
-        my $sid = $dbw->nextval('topics');
+        my $sid = $dbw->nextval('nodes');
         $dbw->xdo(
             insert_into => 'func_new_issue_status',
             values      => {
@@ -268,7 +268,7 @@ sub new_project {
     );
 
     foreach my $status (@status) {
-        my $sid = $dbw->nextval('topics');
+        my $sid = $dbw->nextval('nodes');
         $dbw->xdo(
             insert_into => 'func_new_task_status',
             values      => {
@@ -348,13 +348,13 @@ sub run {
 
             $opts->{message} ||= $self->prompt_edit( opts => $self );
             $opts->{lang}    ||= 'en';
-            $opts->{id}      ||= $dbw->nextval('topics');
+            $opts->{id}      ||= $dbw->nextval('nodes');
             $opts->{change_id} ||= $self->new_change;
 
             $self->new_project;
 
             $self->start_work(
-                topic_id      => $opts->{id},
+                node_id       => $opts->{id},
                 start         => $start,
                 start_comment => "new project",
                 billable      => 1,
@@ -366,15 +366,15 @@ sub run {
             );
 
             $self->save_work(
-                topic_id  => $opts->{id},
+                node_id   => $opts->{id},
                 change_id => $opts->{change_id}
             );
 
             $self->end_change(
-                id                => $opts->{change_id},
-                message           => $opts->{message},
-                action_format     => "new project $opts->{path} (%s)",
-                action_topic_id_1 => $opts->{id},
+                id               => $opts->{change_id},
+                message          => $opts->{message},
+                action_format    => "new project $opts->{path} (%s)",
+                action_node_id_1 => $opts->{id},
             );
 
         }
@@ -394,7 +394,7 @@ bif-new-project - create a new project
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -402,7 +402,7 @@ bif-new-project - create a new project
 
 =head1 DESCRIPTION
 
-The B<bif-new-project> command creates a new project topic.
+The B<bif-new-project> command creates a new project node.
 
 For example, to create a local project:
 
