@@ -9,7 +9,7 @@ use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 use Path::Tiny;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -22,8 +22,7 @@ sub run {
                              #Or handle that in Bif::Role::Sync?
 
     if ( $opts->{location} =~ m!^(ssh://)?(.*)@(.*)! ) {
-        $opts->{name}     = $2;
-        $opts->{location} = path($3)->realpath;
+        $opts->{name} = $2;
     }
     elsif ( -d $opts->{location} ) {
         $opts->{location} = path( $opts->{location} )->realpath;
@@ -51,7 +50,8 @@ sub run {
         debug         => $opts->{debug},
         debug_bifsync => $opts->{debug_bifsync},
         on_update     => sub {
-            $self->lprint("$opts->{name}: $_[0]");
+            my $client = shift;
+            $self->lprint( $client->name . ': ' . $_[0] );
         },
         on_error => sub {
             $error = shift;
@@ -85,7 +85,7 @@ sub run {
                     }
 
                     $self->start_work(
-                        topic_id      => $ref->[0],
+                        node_id       => $ref->[0],
                         start         => $start,
                         start_comment => "pull hub",
                         billable      => 1,
@@ -135,7 +135,7 @@ bif-pull-hub -  import project lists from a remote repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
