@@ -8,7 +8,7 @@ use Coro;
 use DBIx::ThinSQL qw/qv/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -29,7 +29,8 @@ sub run {
         debug         => $opts->{debug},
         debug_bifsync => $opts->{debug_bifsync},
         on_update     => sub {
-            $self->lprint("Importing identity ($opts->{location}): $_[0]");
+            my $client = shift;
+            $self->lprint( $client->name . ': ' . $_[0] );
         },
         on_error => sub {
             $error = shift;
@@ -63,21 +64,21 @@ sub run {
                     my ( $iid, $uuid, $name, $sn ) = $dbw->xlist(
                         select => [
                             'bifkv.identity_id',
-                            '"u" || substr(t.uuid,1,8) AS uuid',
+                            '"u" || substr(n.uuid,1,8) AS uuid',
                             'e.name', 'i.shortname',
                         ],
                         from       => 'bifkv',
-                        inner_join => 'topics t',
-                        on         => 't.id = bifkv.identity_id',
+                        inner_join => 'nodes n',
+                        on         => 'n.id = bifkv.identity_id',
                         inner_join => 'identities i',
-                        on         => 'i.id = t.id',
+                        on         => 'i.id = n.id',
                         inner_join => 'entities e',
                         on         => 'e.id = i.id',
                         where      => { key => 'self' },
                     );
 
                     $self->start_work(
-                        topic_id      => $iid,
+                        node_id       => $iid,
                         start         => $start,
                         start_comment => "pull identity",
                         billable      => 1,
@@ -117,7 +118,7 @@ bif-pull-identity - import an identity from a repository
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
