@@ -5,13 +5,13 @@ use feature 'state';
 use Bif::Mo;
 use DBIx::ThinSQL qw/concat qv/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
-    my $info = $self->get_topic( $opts->{id}, 'issue' );
+    my $info = $self->get_node( $opts->{id}, 'issue' );
     my $dbw  = $self->dbw;
 
     $dbw->txn(
@@ -81,11 +81,11 @@ sub run {
 
                 if (@unsatisfied) {
                     my $name = $dbw->xval(
-                        select     => ['t.name'],
-                        from       => 'topics t',
+                        select     => ['n.name'],
+                        from       => 'nodes n',
                         inner_join => 'hubs h',
                         on         => 'h.id = p.hub_id',
-                        where      => { 't.id' => $pinfo->{id} },
+                        where      => { 'n.id' => $pinfo->{id} },
                     );
 
                     @unsatisfied = join ', ', @unsatisfied;
@@ -111,7 +111,7 @@ sub run {
                     },
                 );
 
-                my $id = $dbw->nextval('topics');
+                my $id = $dbw->nextval('nodes');
 
                 $dbw->xdo(
                     insert_into => [
@@ -130,23 +130,23 @@ sub run {
                 );
 
                 my $src = $dbw->xval(
-                    select => 't.path',
-                    from   => 'topics t',
-                    where  => { 't.id' => $info->{id}, },
+                    select => 'n.path',
+                    from   => 'nodes n',
+                    where  => { 'n.id' => $info->{id}, },
                 );
 
                 my $dest = $dbw->xval(
-                    select => 't.path',
-                    from   => 'topics t',
-                    where  => { 't.id' => $id, },
+                    select => 'n.path',
+                    from   => 'nodes n',
+                    where  => { 'n.id' => $id, },
                 );
 
                 $self->end_change(
-                    id                => $opts->{change_id},
-                    action_format     => "push issue $src (%s) $dest (%s)",
-                    action_topic_id_1 => $info->{id},
-                    action_topic_id_2 => $pinfo->{id},
-                    message           => "[ forked: $src -> $dest ]\n\n"
+                    id               => $opts->{change_id},
+                    action_format    => "push issue $src (%s) $dest (%s)",
+                    action_node_id_1 => $info->{id},
+                    action_node_id_2 => $pinfo->{id},
+                    message          => "[ forked: $src -> $dest ]\n\n"
                       . $opts->{message},
                 );
 
@@ -168,7 +168,7 @@ bif-push-issue - push an issue to another project
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -177,11 +177,11 @@ bif-push-issue - push an issue to another project
 =head1 DESCRIPTION
 
 The B<bif-push-issue> command is used to modify the relationship
-between a topic and a previously unrelated project. The type of the
-topic being pushed determines the type of relationship changes that are
+between a node and a previously unrelated project. The type of the
+node being pushed determines the type of relationship changes that are
 possible.
 
-Pushing an issue for example "shares" that topic with another project.
+Pushing an issue for example "shares" that node with another project.
 Comments made in any project for that issue will appear everywhere
 else, but status changes are project-specific.  In order for that to be
 possible however, the destination project must already be cooperating
