@@ -6,7 +6,7 @@ use Bif::Sync::Client;
 use Bif::Mo;
 use Coro;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -38,7 +38,8 @@ sub run {
         debug         => $opts->{debug},
         debug_bifsync => $opts->{debug_bifsync},
         on_update     => sub {
-            $self->lprint("$hinfo->{name}: $_[0]");
+            my $client = shift;
+            $self->lprint( $client->name . ': ' . $_[0] );
         },
         on_error => sub {
             $error = shift;
@@ -75,8 +76,8 @@ sub run {
                         id            => $opts->{change_id},
                         action_format => "push project $pinfo->{path} "
                           . "(%s) $hinfo->{name}",
-                        action_topic_id_1 => $pinfo->{id},
-                        message           => $msg,
+                        action_node_id_1 => $pinfo->{id},
+                        message          => $msg,
                     );
 
                     $dbw->xdo(
@@ -106,7 +107,7 @@ sub run {
                         }
                     }
 
-                    $status = $client->sync_projects;
+                    $status = $client->sync_project( $pinfo->{id} );
 
                     unless ( $status eq 'ProjectSync'
                         or $status eq 'ProjectMatch' )
@@ -160,7 +161,7 @@ bif-push-project -  export a project to a remote hub
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
