@@ -3,13 +3,13 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
-    my $info = $self->get_topic( $self->uuid2id( $opts->{id} ) );
+    my $info = $self->get_node( $self->uuid2id( $opts->{id} ) );
 
     return $self->new_cmd( "App::bif::show::$info->{kind}",
         opts => { id => $info->{id} } )->run;
@@ -22,11 +22,11 @@ __END__
 
 =for bif-doc #show
 
-bif-show - display a topic's current status
+bif-show - display a node's current status
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -34,9 +34,9 @@ bif-show - display a topic's current status
 
 =head1 DESCRIPTION
 
-The B<bif-show> command displays a summary of a topic's current status.
+The B<bif-show> command displays a summary of a node's current status.
 This command doesn't actually implement anything on its own. It simply
-looks up the type of topic and calls the appropriate B<bif-show-*> sub
+looks up the type of node and calls the appropriate B<bif-show-*> sub
 command.
 
 =head2 Arguments & Options
@@ -45,7 +45,7 @@ command.
 
 =item ID
 
-A topic ID or a project PATH. Required.
+A node ID or a project PATH. Required.
 
 =item --full, -f
 
@@ -53,7 +53,7 @@ Display a more verbose version of the current status.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
