@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::show';
 
 sub run {
@@ -25,11 +25,11 @@ sub run {
     push( @data, $self->header( '  Location', $hub->{location}, ) );
 
     my $info = $db->xhashref(
-        select     => [qw/t.ctime t.ctimetz t.mtime t.mtimetz/],
-        from       => 'topics t',
+        select     => [qw/n.ctime n.ctimetz n.mtime n.mtimetz/],
+        from       => 'nodes n',
         inner_join => 'changes c',
-        on         => 'c.id = t.first_change_id',
-        where      => { 't.id' => $hub->{id} },
+        on         => 'c.id = n.first_change_id',
+        where      => { 'n.id' => $hub->{id} },
     );
 
     $self->start_pager;
@@ -52,7 +52,7 @@ bif-show-hub - display a hub's current status
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,7 @@ Display a more verbose version of the current status.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
