@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/sum case coalesce concat qv/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::show';
 
 sub run {
@@ -20,22 +20,22 @@ sub run {
     my $ref = $db->xhashref(
         select => [
             'i.id',
-            concat( qv('u'), 't.uuid' )->as('uuid'),
+            concat( qv('u'), 'n.uuid' )->as('uuid'),
             'e.name',
             'i.shortname',
-            'ct.contact_id != e.id AS other_contact',
-            'ct.name AS contact',
+            'cn.contact_id != e.id AS other_contact',
+            'cn.name AS contact',
             'e.local',
         ],
         from       => 'identities i',
         inner_join => 'entities e',
         on         => 'e.id = i.id',
-        inner_join => 'topics t',
-        on         => 't.id = i.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = i.id',
         inner_join => 'changes c',
-        on         => 'c.id = t.first_change_id',
-        inner_join => 'entities ct',
-        on         => 'ct.id = e.contact_id',
+        on         => 'c.id = n.first_change_id',
+        inner_join => 'entities cn',
+        on         => 'cn.id = e.contact_id',
         where      => { 'i.id' => $opts->{id} },
     );
 
@@ -102,7 +102,7 @@ bif-show-identity - display a identity's current status
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -127,7 +127,7 @@ Display a more verbose version of the current status.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
