@@ -4,7 +4,7 @@ use warnings;
 use Bif::Mo;
 use DBIx::ThinSQL qw/bv sum case coalesce concat qv sq/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::show';
 
 sub run {
@@ -14,37 +14,37 @@ sub run {
 
     $opts->{id} = $self->uuid2id( $opts->{id} );
 
-    my $info = $self->get_topic( $opts->{id}, 'issue' );
+    my $info = $self->get_node( $opts->{id}, 'issue' );
     my $now = $self->now;
     my @data;
 
     my $ref = $db->xhashref(
         select => [
-            'SUBSTR(t.uuid,1,8) as uuid',
+            'SUBSTR(n.uuid,1,8) as uuid',
             'i.title',
-            't.ctime',
-            't.ctimetz',
-            't.ctimetzhm AS ctimetzhm',
-            "$now - t.ctime AS ctime_age",
-            't.mtime',
-            't.mtimetz',
-            't.mtimetzhm AS mtimetzhm',
-            "$now - t.mtime AS mtime_age",
+            'n.ctime',
+            'n.ctimetz',
+            'n.ctimetzhm AS ctimetzhm',
+            "$now - n.ctime AS ctime_age",
+            'n.mtime',
+            'n.mtimetz',
+            'n.mtimetzhm AS mtimetzhm',
+            "$now - n.mtime AS mtime_age",
             'e1.name as creator',
             'e2.name as updator',
         ],
-        from       => 'topics t',
+        from       => 'nodes n',
         inner_join => 'changes c1',
-        on         => 'c1.id = t.first_change_id',
+        on         => 'c1.id = n.first_change_id',
         inner_join => 'entities e1',
         on         => 'e2.id = c2.identity_id',
         inner_join => 'changes c2',
-        on         => 'c2.id = t.last_change_id',
+        on         => 'c2.id = n.last_change_id',
         inner_join => 'entities e2',
         on         => 'e1.id = c1.identity_id',
         inner_join => 'issues i',
-        on         => 'i.id = t.id',
-        where      => { 't.id' => $info->{id} },
+        on         => 'i.id = n.id',
+        where      => { 'n.id' => $info->{id} },
     );
 
     push( @data, $self->header( '  UUID', $ref->{uuid} ), );
@@ -79,7 +79,7 @@ sub run {
         ),
         select => [
             'i.id AS id',
-            'pt.path',
+            'pn.path',
             'ist.status',
             'c.mtime AS mtime',
             'c.mtimetz AS mtimetz',
@@ -92,15 +92,15 @@ sub run {
         on         => 'i.id = ids.id',
         inner_join => 'projects p',
         on         => 'p.id = i.project_id',
-        inner_join => 'topics pt',
-        on         => 'pt.id = i.project_id',
+        inner_join => 'nodes pn',
+        on         => 'pn.id = i.project_id',
         inner_join => 'issue_status ist',
         on         => 'ist.id = i.issue_status_id',
-        inner_join => 'topics t',
-        on         => 't.id = i.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = i.id',
         inner_join => 'changes c',
-        on         => 'c.id = t.first_change_id',
-        order_by   => 'pt.path',
+        on         => 'c.id = n.first_change_id',
+        order_by   => 'pn.path',
     );
 
     my %seen;
@@ -145,7 +145,7 @@ bif-show-issue - display an issue's current status
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -169,7 +169,7 @@ Display a more verbose version of the current status.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
