@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::show';
 
 sub run {
@@ -19,24 +19,24 @@ sub run {
 
     my $ref = $db->xhashref(
         select => [
-            'pl.id',                 'substr(t.uuid,1,8) as uuid',
+            'pl.id',                 'substr(n.uuid,1,8) as uuid',
             'pl.name',               'pl.title',
-            'e.name AS provider',    't.ctime',
-            't.ctimetz',             't.ctimetzhm AS ctimetzhm',
-            "$now - t.mtime AS age", 't.mtime',
-            't.mtimetz',             't.mtimetzhm AS mtimetzhm',
-            "$now - t.mtime AS age", 'c.author',
+            'e.name AS provider',    'n.ctime',
+            'n.ctimetz',             'n.ctimetzhm AS ctimetzhm',
+            "$now - n.mtime AS age", 'n.mtime',
+            'n.mtimetz',             'n.mtimetzhm AS mtimetzhm',
+            "$now - n.mtime AS age", 'c.author',
             'c.author_contact',      'c.message',
         ],
         from       => 'plans pl',
-        inner_join => 'topics t',
-        on         => 't.id = pl.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = pl.id',
         inner_join => 'providers p',
         on         => 'p.id = pl.provider_id',
         inner_join => 'entities e',
         on         => 'e.id = p.id',
         inner_join => 'changes c',
-        on         => 'c.id = t.first_change_id',
+        on         => 'c.id = n.first_change_id',
         where      => { 'pl.id' => $opts->{id} },
     );
 
@@ -82,7 +82,7 @@ bif-show-plan - display a plan's current status
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ Display a more verbose version of the current status.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
