@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif::show';
 
 sub run {
@@ -19,37 +19,37 @@ sub run {
 
     my $ref = $db->xhashref(
         select => [
-            'topics.id',
-            'substr(topics.uuid,1,8) as uuid',
-            'topics.path',
+            'nodes.id',
+            'substr(nodes.uuid,1,8) as uuid',
+            'nodes.path',
             'projects.title',
-            'topics.ctime AS ctime',
-            'topics.ctimetz AS ctimetz',
-            'topics.ctimetzhm AS ctimetzhm',
-            "$now - topics.ctime AS ctime_age",
-            'topics.mtime AS mtime',
-            'topics.mtimetz AS mtimetz',
-            'topics.mtimetzhm AS mtimetzhm',
-            "$now - topics.mtime AS mtime_age",
+            'nodes.ctime AS ctime',
+            'nodes.ctimetz AS ctimetz',
+            'nodes.ctimetzhm AS ctimetzhm',
+            "$now - nodes.ctime AS ctime_age",
+            'nodes.mtime AS mtime',
+            'nodes.mtimetz AS mtimetz',
+            'nodes.mtimetzhm AS mtimetzhm',
+            "$now - nodes.mtime AS mtime_age",
             'changes.author',
             'changes.author_contact AS contact',
             'changes.message',
             'project_status.status',
             'project_status.status',
             'projects.local',
-            'ht.name AS hub',
-            'ht.uuid AS hub_uuid',
+            'hn.name AS hub',
+            'hn.uuid AS hub_uuid',
             'h.location',
         ],
         from       => 'projects',
-        inner_join => 'topics',
-        on         => 'topics.id = projects.id',
+        inner_join => 'nodes',
+        on         => 'nodes.id = projects.id',
         inner_join => 'changes',
-        on         => 'changes.id = topics.first_change_id',
+        on         => 'changes.id = nodes.first_change_id',
         inner_join => 'project_status',
         on         => 'project_status.id = projects.project_status_id',
-        left_join  => 'topics ht',
-        on         => 'ht.id = projects.default_hub_id',
+        left_join  => 'nodes hn',
+        on         => 'hn.id = projects.default_hub_id',
         left_join  => 'hubs h',
         on         => 'h.id = projects.default_hub_id',
         where      => { 'projects.id' => $info->{id} },
@@ -173,7 +173,7 @@ bif-show-project - display a project's current status
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -209,7 +209,7 @@ Display a more verbose version of the current status.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
