@@ -7,9 +7,11 @@ use DBIx::ThinSQL qw/ sq /;
 use Time::Piece;
 use Time::Seconds;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
+my ( $bold, $reset );
+
 sub _build {
     my $id    = shift;
     my $count = @_;
@@ -65,12 +67,15 @@ sub _build {
         push( @having, "SUM(col$i) >= 60" );
 
         my @x;
+        my @y;
         foreach my $j ( 1 .. $count ) {
             if ( $i == $j ) {
                 push( @x, "wd.stop - wd.start AS col$j" );
+                push( @y, "wb.stop - wb.start AS col$j" );
             }
             else {
                 push( @x, "NULL AS col$j" );
+                push( @y, "NULL AS col$j" );
             }
         }
 
@@ -78,7 +83,7 @@ sub _build {
             @select,
             [
                 ( $i == 1 ? 'select' : 'union_all_select' ) =>
-                  [ 't.kind AS kind', 't.path AS path', @x, ],
+                  [ 'n.kind AS kind', 'n.path AS path', @x, ],
                 from       => 'work_deltas wd',
                 inner_join => 'changes c',
                 on         => {
@@ -87,23 +92,50 @@ sub _build {
                 },
                 $rollup
                 ? (
-                    inner_join => 'topics_tree tt',
-                    on         => 'tt.child = wd.topic_id',
+                    inner_join => 'nodes_tree nt',
+                    on         => 'nt.child = wd.node_id',
                     inner_join => 'projects p',
-                    on         => 'p.id = tt.parent',
+                    on         => 'p.id = nt.parent',
                   )
                 : (
-                    inner_join => 'topics t2',
-                    on         => 't2.id = wd.topic_id',
+                    inner_join => 'nodes n2',
+                    on         => 'n2.id = wd.node_id',
                     inner_join => 'projects p',
-                    on         => 'p.id = t2.project_id',
+                    on         => 'p.id = n2.project_id',
                 ),
-                inner_join                => 'topics t',
-                on                        => 't.id = p.id',
+                inner_join                => 'nodes n',
+                on                        => 'n.id = p.id',
                 "where -- $start -> $end" => {
                     'wd.gtime_start >=' => $start->epoch,
                     'wd.gtime_stop <'   => $end->epoch,
                 },
+                union_all_select => [
+                    'n.kind AS kind',
+                    'n.path || " (' . "${bold}unrec$reset" . ')" AS path', @y,
+                ],
+                from                   => 'bifkv b',
+                inner_join             => 'work_buffers wb',
+                "on -- $start -> $end" => {
+                    'wb.billable'       => 1,
+                    'wb.gtime_start >=' => $start->epoch,
+                    'wb.gtime_stop <'   => $end->epoch,
+                },
+                $rollup
+                ? (
+                    inner_join => 'nodes_tree nt',
+                    on         => 'nt.child = wb.node_id',
+                    inner_join => 'projects p',
+                    on         => 'p.id = nt.parent',
+                  )
+                : (
+                    inner_join => 'nodes n2',
+                    on         => 'n2.id = wb.node_id',
+                    inner_join => 'projects p',
+                    on         => 'p.id = n2.project_id',
+                ),
+                inner_join => 'nodes n',
+                on         => 'n.id = p.id',
+                where      => { key => 'self', identity_id => $id },
             ]
         );
 
@@ -119,7 +151,7 @@ sub _build {
 
             # Time::Piece's %V does not work under windows, so use the
             # ->method() calls instead. See
-            # https://rt.cpan.org/Public/Bug/Display.html?id=105507
+            # https://rn.cpan.org/Public/Bug/Display.html?id=105507
             push( @headers,
                 sprintf( '%0.4d-W%0.2d', $start->year, $start->week ) );
         }
@@ -140,10 +172,12 @@ sub run {
     my $opts = $self->opts;
     my $db   = $self->db;
 
+    ( $bold, $reset ) = $self->colours(qw/bold reset/);
+
     my $id;
     if ( my $str = $self->opts->{identity} ) {
         unless ( $str eq '-' ) {
-            my $iinfo = $self->get_topic( $str, 'identity' );
+            my $iinfo = $self->get_node( $str, 'identity' );
             $id = $iinfo->{id};
         }
     }
@@ -207,7 +241,7 @@ sub run {
     );
 
     if ( !@data ) {
-        print "Timesheet is empty for selected period.\n";
+        print "Timesheet is empty (or < 0:01) for selected period.\n";
     }
     else {
         $self->start_pager;
@@ -242,7 +276,7 @@ bif-show-timesheet - display time worked per project
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
