@@ -7,7 +7,7 @@ use Bif::Mo;
 use Coro;
 use DBIx::ThinSQL qw/qv/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -17,12 +17,12 @@ sub run {
 
     # Consider upping PRAGMA cache_size? Or handle that in Bif::Role::Sync?
     my @hubs = $dbw->xhashrefs(
-        select     => [ 'h.id', 't.name', 'h.location', 't.uuid' ],
+        select     => [ 'h.id', 'n.name', 'h.location', 'n.uuid' ],
         from       => 'hubs h',
-        inner_join => 'topics t',
-        on         => 't.id = h.id',
-        $opts->{hub} ? ( where => { 't.name' => $opts->{hub} } ) : (),
-        order_by => 't.name',
+        inner_join => 'nodes n',
+        on         => 'n.id = h.id',
+        $opts->{hub} ? ( where => { 'n.name' => $opts->{hub} } ) : (),
+        order_by => 'n.name',
     );
 
     return $self->err( 'SyncNone', 'no (matching) hubs found' )
@@ -41,7 +41,8 @@ sub run {
             debug         => $opts->{debug},
             debug_bifsync => $opts->{debug_bifsync},
             on_update     => sub {
-                $self->lprint("$hub->{name}: $_[0]");
+                my $client = shift;
+                $self->lprint( $client->name . ': ' . $_[0] );
             },
             on_error => sub {
                 $error = shift;
@@ -57,7 +58,7 @@ sub run {
                 $dbw->txn(
                     sub {
                         $self->start_work(
-                            topic_id      => $hub->{id},
+                            node_id       => $hub->{id},
                             start         => time,
                             start_comment => "sync",
                             billable      => 1,
@@ -86,29 +87,51 @@ sub run {
                             }
                         }
 
-                        @status = $client->sync_projects;
+                        print "\n";
+                        $self->lprint('');
+                        my $hub_id   = $client->hub_id;
+                        my @projects = $dbw->xhashrefs(
+                            select_distinct =>
+                              [ 'p2.id AS id', 'n.path AS path' ],
+                            from       => 'projects p',
+                            inner_join => 'nodes_tree nt',
+                            on         => 'nt.parent = p.id',
+                            inner_join => 'projects p2',
+                            on         => 'p2.id = nt.child AND p2.local = 1',
+                            inner_join => 'nodes n',
+                            on         => 'n.id = p2.id',
+                            where      => {
+                                'p.default_hub_id' => $hub_id,
+                            },
+                        );
 
-                        unless ( $status[0] eq 'ProjectSync'
-                            or $status[0] eq 'ProjectMatch' )
-                        {
-                            $dbw->rollback;
-                            $error =
-"unexpected ProjectSync/Matc status received: @status";
-                            return;
-                        }
+                        foreach my $project (@projects) {
+                            $client->name("$hub->{name}\[$project->{path}\]");
+                            my $status =
+                              $client->sync_project( $project->{id} );
+                            if ( $status eq 'ProjectSync' ) {
+                                @status =
+                                  $client->transfer_project_related_changes;
 
-                        if ( $status[0] eq 'ProjectSync' ) {
-                            @status = $client->transfer_project_related_changes;
-
-                            if ( $status[0] ne 'TransferProjectRelatedChanges' )
-                            {
+                                if ( $status[0] ne
+                                    'TransferProjectRelatedChanges' )
+                                {
+                                    $dbw->rollback;
+                                    $error =
+"unexpected TransferProjectRelatedChanges status received: @status";
+                                    return;
+                                }
+                            }
+                            elsif ( $status ne 'ProjectMatch' ) {
                                 $dbw->rollback;
                                 $error =
-"unexpected TransferProjectRelatedChanges status received: @status";
-                                return;
+"unexpected sync_project status received: $status";
+                                return $status;
                             }
+
+                            print "\n";
+                            $self->lprint('');
                         }
-                        print "\n";
 
                         $dbw->xdo(
                             insert_or_replace_into =>
@@ -162,7 +185,7 @@ bif-sync -  exchange changes with hubs
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
