@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -15,7 +15,7 @@ sub run {
     $dbw->txn(
         sub {
             $self->start_work(
-                topic_id      => $info->{id},
+                node_id       => $info->{id},
                 start         => time,
                 start_comment => "update hub",
                 billable      => 1,
@@ -52,15 +52,15 @@ sub run {
             );
 
             $self->save_work(
-                topic_id  => $info->{id},
+                node_id   => $info->{id},
                 change_id => $opts->{change_id}
             );
 
             $self->end_change(
-                id                => $opts->{change_id},
-                action_format     => "update hub $info->{path} (%s)",
-                action_topic_id_1 => $info->{id},
-                message           => $opts->{message},
+                id               => $opts->{change_id},
+                action_format    => "update hub $info->{path} (%s)",
+                action_node_id_1 => $info->{id},
+                message          => $opts->{message},
             );
 
         }
@@ -80,7 +80,7 @@ bif-update-hub - update or comment a hub
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
