@@ -3,14 +3,14 @@ use strict;
 use warnings;
 use Bif::Mo;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
     my $self = shift;
     my $opts = $self->opts;
     my $dbw  = $self->dbw;
-    my $info = $self->get_topic( $opts->{id} );
+    my $info = $self->get_node( $opts->{id} );
 
     return $self->err( 'IdentityNotFound', "identity not found: $opts->{id}" )
       unless $info;
@@ -18,7 +18,7 @@ sub run {
     $dbw->txn(
         sub {
             $self->start_work(
-                topic_id      => $info->{id},
+                node_id       => $info->{id},
                 start         => time,
                 start_comment => "update identity",
                 billable      => 1,
@@ -55,15 +55,15 @@ sub run {
             );
 
             $self->save_work(
-                topic_id  => $info->{id},
+                node_id   => $info->{id},
                 change_id => $opts->{change_id}
             );
 
             $self->end_change(
-                id                => $opts->{change_id},
-                message           => $opts->{message},
-                action_format     => "update identity %s",
-                action_topic_id_1 => $info->{id},
+                id               => $opts->{change_id},
+                message          => $opts->{message},
+                action_format    => "update identity %s",
+                action_node_id_1 => $info->{id},
             );
 
         }
@@ -83,7 +83,7 @@ bif-update-identity - update or comment an identity
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
