@@ -6,7 +6,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/case coalesce sq qv/;
 use Text::FormatTable;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -15,7 +15,7 @@ sub run {
     my $id;
     if ( my $str = $self->opts->{identity} ) {
         unless ( $str eq '-' ) {
-            my $iinfo = $self->get_topic( $str, 'identity' );
+            my $iinfo = $self->get_node( $str, 'identity' );
             $id = $iinfo->{id};
         }
     }
@@ -43,7 +43,7 @@ sub work_log_long {
             from   => 'work_buffers wb',
         ),
         select => [
-            'wb.topic_id',
+            'wb.node_id',
             q{strftime('%Y-%m-%d %H:%M:%S', }
               . q{ wb.gtime_start, 'unixepoch') AS start},
             q{wb.start_comment AS start_comment},
@@ -54,13 +54,13 @@ sub work_log_long {
               . q{ src.delta / 3600, }
               . q{ (src.delta - 3600 * (src.delta / 3600)) / 60, }
               . q{ src.delta % 60 ) AS delta},
-            q{COALESCE(printf('%s %s [%s]', t.kind, t.id, t.path),'') AS path},
+            q{COALESCE(printf('%s %s [%s]', n.kind, n.id, n.path),'') AS path},
         ],
         from       => 'src',
         inner_join => 'work_buffers wb',
         on         => 'wb.id = src.id',
-        left_join  => 'topics t',
-        on         => 't.id = wb.topic_id',
+        left_join  => 'nodes n',
+        on         => 'n.id = wb.node_id',
         order_by   => 'wb.id DESC',
     );
     $sth->execute;
@@ -91,6 +91,7 @@ sub work_log_short {
     my $self        = shift;
     my $identity_id = shift;
     my $db          = $self->db;
+    my ( $yellow, $bold, $reset ) = $self->colours( 'yellow', 'bold', 'reset' );
 
     my $sth = $db->xprepare(
         with => 'worked',
@@ -103,21 +104,21 @@ sub work_log_short {
                   . q{ wb.gtime_start, 'unixepoch') AS start_ymd},
                 'wb.gtime_stop AS stop',
                 'wb.stop - wb.start AS delta',
-                't.id AS id',
+                'n.id AS id',
                 'i.shortname AS shortname',
-                'COALESCE(t.path,"-") AS path',
+                'COALESCE(n.path,"-") AS path',
                 q{COALESCE(wb.start_comment || ', ' || wb.stop_comment,}
                   . q{wb.start_comment, wb.stop_comment, '-') AS comment},
                 'wb.billable AS billable',
                 case (
-                    when => 'wb.billable != 1',
-                    then => qv('-'),
-                    else => qv(''),
+                    when => 'wb.billable',
+                    then => qv("(${bold}unrec$reset)"),
+                    else => "'-'",
                 )->as('change_id'),
             ],
             from      => 'work_buffers wb',
-            left_join => 'topics t',
-            on        => 't.id = wb.topic_id',
+            left_join => 'nodes n',
+            on        => 'n.id = wb.node_id',
             $identity_id
             ? (
                 inner_join => 'identities i',
@@ -137,17 +138,17 @@ sub work_log_short {
                   . q{ wd.gtime_start, 'unixepoch') AS start_ymd},
                 'wd.gtime_stop AS stop',
                 'wd.stop - wd.start AS delta',
-                't.id AS id',
+                'n.id AS id',
                 'i.shortname AS shortname',
-                't.path AS path',
+                'n.path AS path',
                 q{COALESCE(wd.start_comment || ', ' || wd.stop_comment,}
                   . q{wd.start_comment, wd.stop_comment, '-') AS comment},
-                '1 AS billable',
+                '0 AS billable',
                 'wd.change_id AS change_id',
             ],
             from       => 'work_deltas wd',
-            inner_join => 'topics t',
-            on         => 't.id = wd.topic_id',
+            inner_join => 'nodes n',
+            on         => 'n.id = wd.node_id',
             inner_join => 'changes c',
             on         => {
                 'c.id' => \'wd.change_id',
@@ -216,10 +217,11 @@ sub work_log_short {
     $sth->execute;
     $self->start_pager;
 
-    my ( $yellow, $bold, $reset ) = $self->colours( 'yellow', 'bold', 'reset' );
-    my $i     = 0;
-    my $table = Text::FormatTable->new(' l  l  l  r  r ');
-    my $first = 1;
+    my $i      = 0;
+    my $format = ' l  l  l  r  r ';
+    my @empty  = ( '-', '', '', '', '' );
+    my $table  = Text::FormatTable->new($format);
+    my $first  = 1;
 
     while ( my $ref = $sth->hashref ) {
 
@@ -228,41 +230,30 @@ sub work_log_short {
             # Every 200 rows or so spit out the table and start again.
             if ( $i > 200 ) {
                 print $table->render( $self->term_width ), "\n";
-                $table = Text::FormatTable->new(' l  l  l  r  r ');
+                $table = Text::FormatTable->new($format);
                 $i     = 1;
             }
             elsif ($i) {
-                $table->row( '-', '', '', '', '' );
+                $table->row(@empty);
             }
 
-            if ( 0 == $ref->{comment} ) {
-                $table->head(
-                    $yellow . $ref->{start_ymd},
-                    'Who', "Activity [today]",
-                    'CID', $ref->{delta_hm} . $reset
-                );
-            }
-            elsif ( 1 == $ref->{comment} ) {
-                $table->head(
-                    $yellow . $ref->{start_ymd},
-                    'Who', "Activity [yesterday]",
-                    'CID', $ref->{delta_hm} . $reset
-                );
-            }
-            else {
-                $table->head(
-                    $yellow . $ref->{start_ymd},
-                    'Who', "Activity [$ref->{comment} days ago]",
-                    'CID', $ref->{delta_hm} . $reset
-                );
-            }
+            $table->head(
+                $yellow . $ref->{start_ymd},
+                0 == $ref->{comment}   ? 'Activity [today]'
+                : 1 == $ref->{comment} ? 'Activity [yesterday]'
+                : "Activity [$ref->{comment} days ago]",
+                'Topic',
+                'CID',
+                $ref->{delta_hm} . $reset
+            );
+
         }
         else {
             $table->row(
                 ( $ref->{stop_hm} ? '' : $bold )
                 . "$ref->{start_hm} - $ref->{stop_hm}",
-                $ref->{shortname},
-                "$ref->{comment} [$ref->{path}]",
+                $ref->{comment},
+                $ref->{path},
                 $ref->{change_id},
                 $ref->{delta_hm} . $reset,
 
@@ -288,7 +279,7 @@ bif-wlog - review work buffer entries
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
