@@ -5,7 +5,7 @@ use Bif::Mo;
 use DBIx::ThinSQL qw/concat coalesce qv/;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'App::bif';
 
 sub run {
@@ -23,7 +23,7 @@ sub run {
               scalar localtime( $work->{start} );
             return $self->ok('Working');
         }
-        print "Not currently working a topic.\n";
+        print "Not currently working a node.\n";
         return $self->ok('NoWork');
     }
 
@@ -44,18 +44,18 @@ sub run {
             return $self->ok('StopWork');
         }
 
-        print "Not currently working a topic.\n";
+        print "Not currently working a node.\n";
         return $self->ok('NoWork');
     }
 
     # Check validity of ID
-    my $info = $self->get_topic( $opts->{id} );
+    my $info = $self->get_node( $opts->{id} );
     $opts->{id} = $info->{id};
 
     # Maybe complain if we are working something else
     if ($work) {
         return $self->err( 'WorkOther', "working %s %s [%s] since %s",
-            $work->{kind}, $work->{id}, $work->{path},
+            $work->{kind}, $work->{node_id}, $work->{path},
             scalar localtime( $work->{start} ) )
           unless $opts->{force};
 
@@ -71,7 +71,7 @@ sub run {
 
     # Finally, start the new work
     $self->start_work(
-        topic_id      => $info->{id},
+        node_id       => $info->{id},
         start         => $epoch,
         start_comment => $opts->{comment},
         billable      => $opts->{not_billable} ? 0 : 1,
@@ -93,11 +93,11 @@ __END__
 
 =head1 NAME
 
-bif-work - track your work on a topic
+bif-work - track your work on a node
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -105,21 +105,20 @@ bif-work - track your work on a topic
 
 =head1 DESCRIPTION
 
-The C<bif-work> command is used to record time spent working on a
-topic.
+The C<bif-work> command is used to record time spent working on a node.
 
-When ID is a valid topic ID then work starts. When ID is a dash '-'
-then work stops. With no arguments C<bif-work> prints the current work
+When ID is a valid node ID then work starts. When ID is a dash '-' then
+work stops. With no arguments C<bif-work> prints the current work
 status.
 
 A COMMENT is required when starting work (will be prompted for if not
 given) and may also be provided when stopping work. Attempting to start
-work when you are already working a topic fails unless the C<--force>
+work when you are already working a node fails unless the C<--force>
 option is used.
 
 B<NOTE:> the work buffer is B<not synchronized> with any hub and will
 therefore be lost if you delete your local repository. The cumulative
-time worked is however recorded during topic updates.
+time worked is however recorded during node updates.
 
 =head1 ARGUMENTS & OPTIONS
 
@@ -127,7 +126,7 @@ time worked is however recorded during topic updates.
 
 =item ID
 
-A topic ID, project PATH, or a single dash "-".
+A node ID, project PATH, or a single dash "-".
 
 =item COMMENT
 
@@ -140,7 +139,7 @@ accept the string "yesterday" in place of "yyyy-mm-dd".
 
 =item --force, -f
 
-Force the working of a topic even when currently working.
+Force the working of a node even when currently working.
 
 =item --not-billable, -B
 
@@ -148,7 +147,7 @@ Do not record this work entry in the next update.
 
 =item --uuid, -U
 
-Lookup the topic using ID as a UUID string instead of a topic integer.
+Lookup the node using ID as a UUID string instead of a node integer.
 
 =back
 
