@@ -13,7 +13,7 @@ use Log::Any::Plugin;
 use OptArgs;
 use Path::Tiny;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 
 sub DBVERSION { 1 }
 sub DBFILE    { 'db-v' . DBVERSION . '.sqlite3' }
@@ -21,7 +21,7 @@ sub DBFILE    { 'db-v' . DBVERSION . '.sqlite3' }
 arg directory => (
     isa     => 'Str',
     comment => 'location of bif repository',
-    default => 'default.bif',
+    default => 'defauln.bif',
 );
 
 opt debug => (
