@@ -6,7 +6,7 @@ use DBIx::ThinSQL ();
 use Carp          ();
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 our @ISA     = ('DBIx::ThinSQL');
 
 sub _connected {
@@ -58,17 +58,17 @@ sub uuid2id {
         # In this case we know we will only get one match back
 
         return $self->xarrayref(
-            select => [ 't.id', 't.uuid', ],
-            from   => 'topics t',
-            where => { 't.uuid' => $uuid },
+            select => [ 'n.id', 'n.uuid', ],
+            from   => 'nodes n',
+            where => { 'n.uuid' => $uuid },
             limit => 1,
         );
     }
 
     return $self->xarrayrefs(
-        select_distinct => [ 't.id',         't.uuid AS uuid', ],
-        from            => 'topics t',
-        where           => [ 't.uuid LIKE ', qv( $uuid . '%' ) ],
+        select_distinct => [ 'n.id',         'n.uuid AS uuid', ],
+        from            => 'nodes n',
+        where           => [ 'n.uuid LIKE ', qv( $uuid . '%' ) ],
     );
 }
 
@@ -81,14 +81,14 @@ sub get_change {
         my $change_id = $2;
         my $data      = $self->xhashref(
             select => [
-                'topics.id',   'topics.kind',
-                'topics.uuid', 'changes.id AS change_id',
+                'nodes.id',   'nodes.kind',
+                'nodes.uuid', 'changes.id AS change_id',
                 qv(undef)->as('project_id'),
             ],
-            from       => 'topics',
+            from       => 'nodes',
             inner_join => 'changes',
             on         => { 'changes.id' => $change_id },
-            where      => { 'topics.id' => $id },
+            where      => { 'nodes.id' => $id },
         );
         return $data;
     }
@@ -115,20 +115,20 @@ sub get_projects {
     if ( $path =~ m/^\d+$/ ) {
         return $self->xhashrefs(
             select => [
-                't.id AS id',
-                't.kind AS kind',
-                't.uuid AS uuid',
+                'n.id AS id',
+                'n.kind AS kind',
+                'n.uuid AS uuid',
                 'p.parent_id AS parent_id',
-                't.path AS path',
-                't.first_change_id AS first_change_id',
+                'n.path AS path',
+                'n.first_change_id AS first_change_id',
                 'p.default_hub_id AS default_hub_id',
                 'p.local AS local',
                 'h.name AS hub_name',
             ],
             from       => 'projects p',
-            inner_join => 'topics t',
-            on         => 't.id = p.id',
-            left_join  => 'topics h',
+            inner_join => 'nodes n',
+            on         => 'n.id = p.id',
+            left_join  => 'nodes h',
             on         => 'h.id = p.default_hub_id',
             where      => { 'p.id' => $path },
         );
@@ -136,23 +136,23 @@ sub get_projects {
 
     return $self->xhashrefs(
         select => [
-            't.id AS id',
-            't.kind AS kind',
-            't.uuid AS uuid',
-            't.parent_id AS parent_id',
-            't.path AS path',
-            't.first_change_id AS first_change_id',
+            'n.id AS id',
+            'n.kind AS kind',
+            'n.uuid AS uuid',
+            'n.parent_id AS parent_id',
+            'n.path AS path',
+            'n.first_change_id AS first_change_id',
             'p.default_hub_id AS default_hub_id',
             'p.local AS local',
             'h.name AS hub_name',
         ],
-        from       => 'topics t',
+        from       => 'nodes n',
         inner_join => 'projects p',
-        on         => 'p.id = t.id',
-        left_join  => 'topics h',
+        on         => 'p.id = n.id',
+        left_join  => 'nodes h',
         on         => 'h.id = p.default_hub_id',
-        where      => [ 't.path = ', qv($path), ' OR t.name = ', qv($path) ],
-        order_by   => [qw/t.path/],
+        where      => [ 'n.path = ', qv($path), ' OR n.name = ', qv($path) ],
+        order_by   => [qw/n.path/],
     );
 }
 
@@ -187,18 +187,18 @@ sub get_hub {
 
     return $self->xhashref(
         select => [
-            qw/h.id t.name t.kind t.uuid h.location t.first_change_id/,
+            qw/h.id n.name n.kind n.path n.uuid h.location n.first_change_id/,
             , 'b.hub_id AS is_default'
         ],
-        from       => 'topics t',
+        from       => 'nodes n',
         inner_join => 'hubs h',
-        on         => 'h.id = t.id',
+        on         => 'h.id = n.id',
         inner_join => 'projects p',
         on         => 'p.id = h.id',
         left_join  => 'bifkv b',
         on         => 'b.key = "local" AND b.hub_id = h.id',
         where      => [
-            't.name = ',   qv($hub), ' OR h.location = ', qv($hub),
+            'n.name = ',   qv($hub), ' OR h.location = ', qv($hub),
             ' OR h.id = ', qv($hub)
         ],
     );
@@ -264,7 +264,7 @@ Bif::DB - helper methods for a read-only bif database
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
@@ -291,8 +291,7 @@ parts are separated for performance reasons.
 
 =item uuid2id( $UUID ) -> List[Int]
 
-Returns the (possibly multiple) integer ID(s) matching a topic
-C<$UUID>.
+Returns the (possibly multiple) integer ID(s) matching a node C<$UUID>.
 
 =item get_change( "$ID.$UPDATE_ID" ) -> HashRef
 
@@ -301,19 +300,19 @@ or a hash reference containg the following keys:
 
 =over
 
-=item * id - the topic ID
+=item * id - the node ID
 
 =item * change_id - the ID of the change
 
-=item * kind - the type of the topic
+=item * kind - the type of the node
 
-=item * uuid - the universally unique identifier of the topic
+=item * uuid - the universally unique identifier of the node
 
 =back
 
 =item get_local_hub_id -> Int
 
-Returns the ID for the local repository topic.
+Returns the ID for the local repository node.
 
 =item get_projects( $PATH ) -> @HashRefs | \@HashRefs
 
@@ -322,13 +321,13 @@ and returns a list of hash references containg the following keys:
 
 =over
 
-=item * id - the topic ID
+=item * id - the node ID
 
-=item * first_change_id - the change_id that created the topic
+=item * first_change_id - the change_id that created the node
 
-=item * kind - the type of the topic
+=item * kind - the type of the node
 
-=item * uuid - the universally unique identifier of the topic
+=item * uuid - the universally unique identifier of the node
 
 =item * path - the path of the project
 
@@ -361,13 +360,17 @@ identified by C<$name> with the following keys:
 
 =over
 
-=item * id - the topic ID for the hub
+=item * first_change_id - the first change ID
 
-=item * name - the name of the hub
+=item * id - the node ID for the hub
 
 =item * location - the location of the hub
 
-=item * is_default - true if it is the default location
+=item * name - the name of the hub
+
+=item * path - the path of the hub node
+
+=item * uuid - the node unique identifier
 
 =back
 
