@@ -5,7 +5,7 @@ use Bif::DB::Plugin::ChangeUUIDv1;
 use Clone 'clone';
 use DBIx::ThinSQL qw/case qv/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 
 my %statements;
 
@@ -67,19 +67,19 @@ sub Bif::DB::db::changeset_v1 {
     my $end_change = $prepared{$self}{end_change} ||= $self->xprepare(
         select => [
             'c.action_format AS action_format',
-            't1.id AS action_topic_id_1',
-            't2.id AS action_topic_id_2',
+            'n1.id AS action_node_id_1',
+            'n2.id AS action_node_id_2',
             'i.id AS identity_id',
             'c.message AS message',
             'c.id AS id',
         ],
         from       => 'changes c',
-        inner_join => 'topics i',
+        inner_join => 'nodes i',
         on         => 'i.id = c.identity_id',
-        left_join  => 'topics t1',
-        on         => 't1.id = c.action_topic_id_1',
-        left_join  => 'topics t2',
-        on         => 't2.id = c.action_topic_id_2',
+        left_join  => 'nodes n1',
+        on         => 'n1.id = c.action_node_id_1',
+        left_join  => 'nodes n2',
+        on         => 'n2.id = c.action_node_id_2',
         where      => 'c.id = ?',
     );
 
@@ -156,7 +156,7 @@ database
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
