@@ -3,33 +3,33 @@ use strict;
 use warnings;
 use DBIx::ThinSQL qw/case qv/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 
 our %statements = (
     new_hub => [
         select => [
             '"new_hub" AS _delta',
             'hd.location AS location',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'hub_deltas hd',
-        inner_join => 'topics t',
-        on         => 't.id = hd.hub_id',
+        inner_join => 'nodes n',
+        on         => 'n.id = hd.hub_id',
         where      => 'hd.id = ?',
     ],
 
     update_hub => [
         select => [
             '"update_hub" AS _delta',
-            'td.name AS name',
+            'nd.name AS name',
             'pd.title AS title',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'project_deltas pd',
-        inner_join => 'topic_deltas td',
-        on         => 'td.id = pd.id',
-        inner_join => 'topics t',
-        on         => 't.id = pd.project_id',
+        inner_join => 'node_deltas nd',
+        on         => 'nd.id = pd.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = pd.project_id',
         where      => 'pd.id = ?',
     ],
 
@@ -41,9 +41,9 @@ our %statements = (
             'hr.uuid AS uuid',
         ],
         from       => 'hub_repo_deltas hrd',
-        inner_join => 'topics hr',
+        inner_join => 'nodes hr',
         on         => 'hr.id = hrd.hub_repo_id',
-        left_join  => 'topics h',
+        left_join  => 'nodes h',
         on         => 'h.id = hrd.hub_id',
         where      => 'hrd.id = ?',
     ],
@@ -56,9 +56,9 @@ our %statements = (
             'hr.uuid AS uuid',
         ],
         from       => 'hub_repo_deltas hrd',
-        inner_join => 'topics hr',
+        inner_join => 'nodes hr',
         on         => 'hr.id = hrd.hub_repo_id',
-        left_join  => 'topics h',
+        left_join  => 'nodes h',
         on         => 'h.id = hrd.hub_id',
         where      => 'hrd.id = ?',
     ],
@@ -75,11 +75,11 @@ our %statements = (
         from       => 'identity_deltas id',
         inner_join => 'entity_deltas ed',
         on         => 'ed.id = id.id',
-        inner_join => 'topics i',
+        inner_join => 'nodes i',
         on         => 'i.id = id.identity_id',
-        left_join  => 'topics con',
+        left_join  => 'nodes con',
         on         => 'con.id = ed.contact_id',
-        left_join  => 'topics dcm',
+        left_join  => 'nodes dcm',
         on         => 'dcm.id = ed.default_contact_method_id',
         where      => 'id.id = ?',
     ],
@@ -87,7 +87,7 @@ our %statements = (
     update_identity => [
         select => [
             '"update_identity" AS _delta',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
             'ed.name AS name',
             'id.shortname AS shortname',
             'con.uuid AS contact_uuid',
@@ -96,11 +96,11 @@ our %statements = (
         from       => 'identity_deltas id',
         inner_join => 'entity_deltas ed',
         on         => 'ed.id = id.id',
-        inner_join => 'topics t',
-        on         => 't.id = id.identity_id',
-        left_join  => 'topics con',
+        inner_join => 'nodes n',
+        on         => 'n.id = id.identity_id',
+        left_join  => 'nodes con',
         on         => 'con.id = ed.contact_id',
-        left_join  => 'topics dcm',
+        left_join  => 'nodes dcm',
         on         => 'dcm.id = ed.default_contact_method_id',
         where      => 'id.id = ?',
     ],
@@ -111,27 +111,27 @@ our %statements = (
             'i.uuid AS identity_uuid',
             'ecmd.method AS method',
             'ecmd.mvalue AS mvalue',
-            'ecmt.uuid AS uuid',
+            'ecmn.uuid AS uuid',
         ],
         from       => 'entity_contact_method_deltas ecmd',
         inner_join => 'entity_contact_methods ecm',
         on         => 'ecm.id = ecmd.entity_contact_method_id',
-        inner_join => 'topics ecmt',
-        on         => 'ecmt.id = ecm.id',
-        inner_join => 'topics i',
+        inner_join => 'nodes ecmn',
+        on         => 'ecmn.id = ecm.id',
+        inner_join => 'nodes i',
         on         => 'i.id = ecm.entity_id',
         where      => 'ecmd.id = ?',
     ],
 
     update_identity_contact_method => [
         select => [
-            't.uuid AS identity_contact_method_uuid',
+            'n.uuid AS identity_contact_method_uuid',
             'ecmd.method AS method',
             'ecmd.mvalue AS mvalue',
         ],
         from       => 'entity_contact_method_deltas ecmd',
-        inner_join => 'topics t',
-        on         => 't.id = ecmd.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = ecmd.id',
         where      => 'ecmd.id = ?',
     ],
 
@@ -141,16 +141,16 @@ our %statements = (
             's.uuid AS issue_status_uuid',
             'src.uuid AS src_uuid',
             'id.title AS title',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'issue_deltas id',
-        inner_join => 'topics t',
-        on         => 't.id = id.issue_id',
-        inner_join => 'topics s',
+        inner_join => 'nodes n',
+        on         => 'n.id = id.issue_id',
+        inner_join => 'nodes s',
         on         => 's.id = id.issue_status_id',
         left_join  => 'issues i',
         on         => 'i.id = id.issue_id',
-        left_join  => 'topics src',
+        left_join  => 'nodes src',
         on         => 'src.id = i.src_id',
         where      => 'id.id = ?',
     ],
@@ -160,12 +160,12 @@ our %statements = (
             '"update_issue" AS _delta',
             'ist.uuid AS issue_status_uuid',
             'id.title AS title',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'issue_deltas id',
-        inner_join => 'topics t',
-        on         => 't.id = id.issue_id',
-        left_join  => 'topics ist',
+        inner_join => 'nodes n',
+        on         => 'n.id = id.issue_id',
+        left_join  => 'nodes ist',
         on         => 'ist.id = id.issue_status_id',
         where      => 'id.id = ?',
     ],
@@ -177,14 +177,14 @@ our %statements = (
             'p.uuid AS project_uuid',
             'isd.rank AS rank',
             'isd.status AS status',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'issue_status_deltas isd',
         inner_join => 'issue_status ist',
         on         => 'ist.id = isd.issue_status_id',
-        inner_join => 'topics t',
-        on         => 't.id = ist.id',
-        inner_join => 'topics p',
+        inner_join => 'nodes n',
+        on         => 'n.id = ist.id',
+        inner_join => 'nodes p',
         on         => 'p.id = ist.project_id',
         where      => 'isd.id = ?',
     ],
@@ -198,7 +198,7 @@ our %statements = (
             'ist.uuid AS uuid',
         ],
         from       => 'issue_status_deltas isd',
-        inner_join => 'topics ist',
+        inner_join => 'nodes ist',
         on         => 'ist.id = ist.id',
         where      => 'isd.id = ?',
     ],
@@ -206,18 +206,18 @@ our %statements = (
     new_project => [
         select => [
             '"new_project" AS _delta',
-            'td.name AS name',
+            'nd.name AS name',
             'pp.uuid AS parent_uuid',
             'pd.title AS title',
             'p.uuid AS uuid',
         ],
         from       => 'project_deltas pd',
-        inner_join => 'topic_deltas td',
-        on         => 'td.id = pd.id',
-        inner_join => 'topics p',
+        inner_join => 'node_deltas nd',
+        on         => 'nd.id = pd.id',
+        inner_join => 'nodes p',
         on         => 'p.id = pd.project_id',
-        left_join  => 'topics pp',
-        on         => 'pp.id = td.parent_id',
+        left_join  => 'nodes pp',
+        on         => 'pp.id = nd.parent_id',
         where      => 'pd.id = ?',
     ],
 
@@ -225,22 +225,22 @@ our %statements = (
         select => [
             '"update_project" AS _delta',
             'h.uuid AS hub_uuid',
-            'td.name AS name',
+            'nd.name AS name',
             'pp.uuid AS parent_uuid',
             'ps.uuid AS project_status_uuid',
             'pd.title AS title',
             'p.uuid AS uuid',
         ],
         from       => 'project_deltas pd',
-        inner_join => 'topic_deltas td',
-        on         => 'td.id = pd.id',
-        inner_join => 'topics p',
+        inner_join => 'node_deltas nd',
+        on         => 'nd.id = pd.id',
+        inner_join => 'nodes p',
         on         => 'p.id = pd.project_id',
-        left_join  => 'topics ps',
+        left_join  => 'nodes ps',
         on         => 'ps.id = pd.project_status_id',
-        left_join  => 'topics pp',
-        on         => 'pp.id = td.parent_id',
-        left_join  => 'topics h',
+        left_join  => 'nodes pp',
+        on         => 'pp.id = nd.parent_id',
+        left_join  => 'nodes h',
         on         => 'h.id = pd.hub_id',
         where      => 'pd.id = ?',
     ],
@@ -251,14 +251,14 @@ our %statements = (
             'p.uuid AS project_uuid',
             'psd.rank AS rank',
             'psd.status AS status',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'project_status_deltas psd',
         inner_join => 'project_status ps',
         on         => 'ps.id = psd.project_status_id',
-        inner_join => 'topics t',
-        on         => 't.id = ps.id',
-        inner_join => 'topics p',
+        inner_join => 'nodes n',
+        on         => 'n.id = ps.id',
+        inner_join => 'nodes p',
         on         => 'p.id = ps.project_id',
         where      => 'psd.id = ?',
     ],
@@ -271,7 +271,7 @@ our %statements = (
             'ps.uuid AS uuid',
         ],
         from       => 'project_status_deltas psd',
-        inner_join => 'topics ps',
+        inner_join => 'nodes ps',
         on         => 'ps.id = psd.project_status_id',
         where      => 'psd.id = ?',
     ],
@@ -280,30 +280,30 @@ our %statements = (
         select => [
             '"new_task" AS _delta',
             'ts.uuid AS task_status_uuid',
-            'td.title AS title',
-            't.uuid AS uuid',
+            'nd.title AS title',
+            'n.uuid AS uuid',
         ],
-        from       => 'task_deltas td',
-        inner_join => 'topics t',
-        on         => 't.id = td.task_id',
-        inner_join => 'topics ts',
-        on         => 'ts.id = td.task_status_id',
-        where      => 'td.id = ?',
+        from       => 'task_deltas nd',
+        inner_join => 'nodes n',
+        on         => 'n.id = nd.task_id',
+        inner_join => 'nodes ts',
+        on         => 'ts.id = nd.task_status_id',
+        where      => 'nd.id = ?',
     ],
 
     update_task => [
         select => [
             '"update_task" AS _delta',
             'ts.uuid AS task_status_uuid',
-            'td.title AS title',
-            't.uuid AS uuid',
+            'nd.title AS title',
+            'n.uuid AS uuid',
         ],
-        from       => 'task_deltas td',
-        inner_join => 'topics t',
-        on         => 't.id = td.task_id',
-        left_join  => 'topics ts',
-        on         => 'ts.id = td.task_status_id',
-        where      => 'td.id = ?',
+        from       => 'task_deltas nd',
+        inner_join => 'nodes n',
+        on         => 'n.id = nd.task_id',
+        left_join  => 'nodes ts',
+        on         => 'ts.id = nd.task_status_id',
+        where      => 'nd.id = ?',
     ],
 
     new_task_status => [
@@ -313,14 +313,14 @@ our %statements = (
             'p.uuid AS project_uuid',
             'tsd.rank AS rank',
             'tsd.status AS status',
-            't.uuid AS uuid',
+            'n.uuid AS uuid',
         ],
         from       => 'task_status_deltas tsd',
         inner_join => 'task_status ts',
         on         => 'ts.id = tsd.task_status_id',
-        inner_join => 'topics t',
-        on         => 't.id = ts.id',
-        inner_join => 'topics p',
+        inner_join => 'nodes n',
+        on         => 'n.id = ts.id',
+        inner_join => 'nodes p',
         on         => 'p.id = ts.project_id',
         where      => 'tsd.id = ?',
     ],
@@ -334,7 +334,7 @@ our %statements = (
             'ts.uuid AS uuid',
         ],
         from       => 'task_status_deltas tsd',
-        inner_join => 'topics ts',
+        inner_join => 'nodes ts',
         on         => 'ts.id = ts.id',
         where      => 'tsd.id = ?',
     ],
@@ -347,11 +347,11 @@ our %statements = (
             'wd.stop AS stop',
             'wd.start_comment AS start_comment',
             'wd.stop_comment AS stop_comment',
-            't.uuid AS topic_uuid',
+            'n.uuid AS node_uuid',
         ],
         from       => 'work_deltas wd',
-        inner_join => 'topics t',
-        on         => 't.id = wd.topic_id',
+        inner_join => 'nodes n',
+        on         => 'n.id = wd.node_id',
         where      => 'wd.id = ?',
     ],
 
@@ -409,19 +409,19 @@ sub Bif::DB::db::uchangeset_v1 {
     my $end_change = $prepared{$self}{end_change} ||= $self->xprepare(
         select => [
             'c.action_format AS action_format',
-            't1.uuid AS action_topic_uuid_1',
-            't2.uuid AS action_topic_uuid_2',
+            'n1.uuid AS action_node_uuid_1',
+            'n2.uuid AS action_node_uuid_2',
             'i.uuid AS identity_uuid',
             'c.message AS message',
             'c.uuid AS uuid',
         ],
         from       => 'changes c',
-        inner_join => 'topics i',
+        inner_join => 'nodes i',
         on         => 'i.id = c.identity_id',
-        left_join  => 'topics t1',
-        on         => 't1.id = c.action_topic_id_1',
-        left_join  => 'topics t2',
-        on         => 't2.id = c.action_topic_id_2',
+        left_join  => 'nodes n1',
+        on         => 'n1.id = c.action_node_id_1',
+        left_join  => 'nodes n2',
+        on         => 'n2.id = c.action_node_id_2',
         where      => 'c.id = ?',
     );
 
@@ -532,7 +532,7 @@ database
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
