@@ -8,13 +8,10 @@ use Coro::Handle;
 use Log::Any '$log';
 use Sys::Cmd qw/spawn/;
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 extends 'Bif::Sync';
 
-has name => (
-    is       => 'ro',
-    required => 1,
-);
+has name => ( required => 1, );
 
 has location => ( is => 'ro', );
 
@@ -45,7 +42,7 @@ has wh => ( is => 'rw' );
 
 sub BUILD {
     my $self = shift;
-    $self->on_update->('connecting...');
+    $self->trigger_on_update('connecting...');
 
     if ( $self->location =~ m!^ssh://(.+)! ) {
         $self->child(
@@ -123,32 +120,46 @@ sub BUILD {
 
 sub trigger_on_update {
     my $self = shift;
+
+    if ( my $msg = shift ) {
+        return $self->on_update->( $self, $msg );
+    }
+
     if ( $self->changes_tosend ) {
         if ( $self->changes_torecv ) {
-            $self->on_update->( 'sent: '
+            $self->on_update->(
+                $self,
+                'sent: '
                   . ( $self->changes_sent // '' ) . '/'
                   . $self->changes_tosend
                   . ' received: '
                   . ( $self->changes_recv // '' ) . '/'
                   . $self->changes_torecv
                   . ' duplicates: '
-                  . $self->changes_dup );
+                  . $self->changes_dup
+            );
         }
         else {
-            $self->on_update->( 'sent: '
+            $self->on_update->(
+                $self,
+                'sent: '
                   . ( $self->changes_sent // '' ) . '/'
-                  . $self->changes_tosend );
+                  . $self->changes_tosend
+            );
         }
     }
     elsif ( $self->changes_torecv ) {
-        $self->on_update->( 'received: '
+        $self->on_update->(
+            $self,
+            'received: '
               . ( $self->changes_recv // '' ) . '/'
               . $self->changes_torecv
               . ' duplicates: '
-              . $self->changes_dup );
+              . $self->changes_dup
+        );
     }
     else {
-        $self->on_update->('no changes');
+        $self->on_update->( $self, 'no changes' );
     }
 }
 
@@ -168,11 +179,11 @@ sub bootstrap_identity {
 
     my $dbw = $self->db;
     my ( $iid, $uid ) = $dbw->xlist(
-        select     => [ 't.id', 't.first_change_id' ],
-        from       => 'topics t',
+        select     => [ 'n.id', 'n.first_change_id' ],
+        from       => 'nodes n',
         inner_join => 'identities i',
-        on         => 'i.id = t.id',
-        where => { 't.uuid' => $uuid, },
+        on         => 'i.id = n.id',
+        where => { 'n.uuid' => $uuid, },
     );
 
     return 'IdentityNotImported' unless $iid;
@@ -205,10 +216,10 @@ sub sync_hub {
     my $id = shift || die 'sync_hub($id)';
 
     my $hub = $self->db->xhashref(
-        select     => [ 't.uuid', 'h.hash' ],
+        select     => [ 'n.uuid', 'h.hash' ],
         from       => 'hubs h',
-        inner_join => 'topics t',
-        on         => 't.id = h.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = h.id',
         where => { 'h.id' => $id },
     );
 
@@ -222,7 +233,7 @@ sub sync_hub {
       and defined $hash;
 
     if ( $hash eq $hub->{hash} ) {
-        $self->on_update->('no changes');
+        $self->trigger_on_update('no changes');
         return 'HubMatch';
     }
 
@@ -238,46 +249,15 @@ sub transfer_hub_changes {
     return $self->real_transfer_hub_changes;
 }
 
-sub sync_projects {
-    my $self   = shift;
-    my $hub_id = $self->hub_id;
-
-    my @ids = $self->db->xvals(
-        select_distinct => 'p2.id',
-        from            => 'projects p',
-        inner_join      => 'topics_tree tt',
-        on              => 'tt.parent = p.id',
-        inner_join      => 'projects p2',
-        on              => 'p2.id = tt.child AND p2.local = 1',
-        where           => {
-            'p.default_hub_id' => $self->hub_id,
-        },
-    );
-
-    my $sync;
-    foreach my $id (@ids) {
-        my $status = $self->sync_project($id);
-        if ( $status eq 'ProjectSync' ) {
-            $sync++;
-        }
-        elsif ( $status ne 'ProjectMatch' ) {
-            return $status;
-        }
-    }
-
-    return 'ProjectSync' if $sync;
-    return 'ProjectMatch';
-}
-
 sub sync_project {
     my $self = shift;
     my $id = shift || die 'sync_project($id)';
 
     my $pinfo = $self->db->xhashref(
-        select     => [ 't.uuid', 'p.hash', 't.id' ],
+        select     => [ 'n.uuid', 'p.hash', 'n.id' ],
         from       => 'projects p',
-        inner_join => 'topics t',
-        on         => 't.id = p.id',
+        inner_join => 'nodes n',
+        on         => 'n.id = p.id',
         where      => {
             'p.id' => $id,
         },
@@ -293,7 +273,7 @@ sub sync_project {
       and defined $hash;
 
     if ( $hash eq $pinfo->{hash} ) {
-        $self->on_update->('no changes');
+        $self->trigger_on_update('no changes');
         return 'ProjectMatch';
     }
 
@@ -381,7 +361,7 @@ Bif::Sync::Client - client for communication with a bif hub
 
 =head1 VERSION
 
-0.1.5_4 (2015-08-04)
+0.1.5_5 (2015-08-13)
 
 =head1 SYNOPSIS
 
