@@ -4,7 +4,7 @@ use warnings;
 use DBIx::ThinSQL qw/qv sq/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 
 sub Bif::Sync::real_import_project {
     my $self   = shift;
@@ -51,7 +51,7 @@ sub Bif::Sync::real_export_project {
         $total,
         [
             select => 'pc.change_id AS id',
-            from   => 'project_changes pc',
+            from   => 'project_related_changes pc',
             where  => {
                 'pc.project_id'  => $id,
                 'pc.change_id !' => undef,
