@@ -4,7 +4,7 @@ use warnings;
 use DBIx::ThinSQL qw/qv sq/;
 use Log::Any '$log';
 
-our $VERSION = '0.1.5_4';
+our $VERSION = '0.1.5_5';
 
 sub Bif::Sync::real_import_hub {
     my $self   = shift;
@@ -89,7 +89,7 @@ sub Bif::Sync::real_export_hub {
         $total,
         [
             select => 'hc.change_id AS id',
-            from   => 'hub_changes hc',
+            from   => 'hub_related_changes hc',
             where  => {
                 'hc.hub_id'      => $id,
                 'hc.change_id !' => undef,
