@@ -1,8 +1,8 @@
 CREATE TABLE func_end_change(
     id INTEGER NOT NULL,
     action_format VARCHAR NOT NULL,
-    action_topic_id_1 INTEGER,
-    action_topic_id_2 INTEGER,
+    action_node_id_1 INTEGER,
+    action_node_id_2 INTEGER,
     identity_id INTEGER NOT NULL,
     message VARCHAR NOT NULL,
     uuid VARCHAR(40)
@@ -19,8 +19,8 @@ BEGIN
     SELECT debug(
         NEW.id,
         NEW.action_format,
-        NEW.action_topic_id_1,
-        NEW.action_topic_id_2,
+        NEW.action_node_id_1,
+        NEW.action_node_id_2,
         NEW.identity_id,
         NEW.message,
         NEW.uuid
@@ -30,23 +30,23 @@ BEGIN
         changes
     SET
         action_format     = NEW.action_format,
-        action_topic_id_1 = NEW.action_topic_id_1,
-        action_topic_id_2 = NEW.action_topic_id_2,
+        action_node_id_1 = NEW.action_node_id_1,
+        action_node_id_2 = NEW.action_node_id_2,
         identity_id       = NEW.identity_id,
         message           = NEW.message,
         action = (
             SELECT
-                printf(NEW.action_format, t1.id, t2.id)
+                printf(NEW.action_format, n1.id, n2.id)
             FROM
                 (SELECT 1)
             LEFT JOIN
-                topics t1
+                nodes n1
             ON
-                t1.id = NEW.action_topic_id_1
+                n1.id = NEW.action_node_id_1
             LEFT JOIN
-                topics t2
+                nodes n2
             ON
-                t2.id = NEW.action_topic_id_2
+                n2.id = NEW.action_node_id_2
         ),
         yaml = yaml || (
             SELECT
@@ -59,10 +59,10 @@ BEGIN
                     '  action_format: ' 
                     || COALESCE(NEW.action_format,'~') || x'0A'
                 END
-                || '  action_topic_uuid_1: '
-                || COALESCE(t1.uuid, '~') || x'0A'
-                || '  action_topic_uuid_2: '
-                || COALESCE(t2.uuid, '~') || x'0A'
+                || '  action_node_uuid_1: '
+                || COALESCE(n1.uuid, '~') || x'0A'
+                || '  action_node_uuid_2: '
+                || COALESCE(n2.uuid, '~') || x'0A'
                 || '  identity_uuid: ' || COALESCE(i.uuid,'~') || x'0A'
                 ||
                     CASE WHEN
@@ -95,15 +95,15 @@ BEGIN
             FROM
                 (SELECT 1)
             LEFT JOIN
-                topics t1
+                nodes n1
             ON
-                t1.id = NEW.action_topic_id_1
+                n1.id = NEW.action_node_id_1
             LEFT JOIN
-                topics t2
+                nodes n2
             ON
-                t2.id = NEW.action_topic_id_2
+                n2.id = NEW.action_node_id_2
             LEFT JOIN
-                topics i
+                nodes i
             ON
                 i.id = NEW.identity_id
         )
@@ -161,17 +161,6 @@ BEGIN
     ;
 */
 
-    /*
-        Now that identity_id has been set we can do some cleanup of the
-        project/entities relationship
-    UPDATE
-        project_changes
-    SET
-        map_entities = 1
-    WHERE
-        change_id = NEW.id AND map_entities = 0
-    ;
-    */
 
     SELECT RAISE(IGNORE);
 END;
