@@ -1,6 +1,6 @@
 CREATE TABLE func_import_new_entity(
     change_uuid VARCHAR(40) NOT NULL,
-    topic_uuid VARCHAR(40) NOT NULL,
+    node_uuid VARCHAR(40) NOT NULL,
     contact_uuid VARCHAR(40),
     default_contact_method_uuid VARCHAR(40),
     name VARCHAR NOT NULL
@@ -15,7 +15,7 @@ BEGIN
 
     SELECT debug(
         NEW.change_uuid,
-        NEW.topic_uuid,
+        NEW.node_uuid,
         NEW.contact_uuid,
         NEW.default_contact_method_uuid,
         NEW.name
@@ -31,22 +31,22 @@ BEGIN
         )
     SELECT
         c.id,
-        t.id,
-        ct.id,
+        n.id,
+        cn.id,
         ecm.id,
         NEW.name
     FROM
         changes c
     INNER JOIN
-        topics t
+        nodes n
     ON
-        t.uuid = NEW.topic_uuid
+        n.uuid = NEW.node_uuid
     LEFT JOIN
-        topics ct
+        nodes cn
     ON
-        ct.uuid = NEW.contact_uuid
+        cn.uuid = NEW.contact_uuid
     LEFT JOIN
-        topics ecm
+        nodes ecm
     ON
         ecm.uuid = NEW.default_contact_method_uuid
     WHERE
