@@ -28,12 +28,12 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         h.id,
         NEW.location,
         NEW.uuid
     FROM
-        topics h
+        nodes h
     WHERE
         h.uuid = NEW.hub_uuid
     ;
