@@ -31,15 +31,15 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         ist.id,
         NEW.title,
         s.id,
         NEW.uuid
     FROM
-        topics ist
+        nodes ist
     LEFT JOIN
-        topics s
+        nodes s
     ON
         s.uuid = NEW.src_uuid
     WHERE
