@@ -31,7 +31,7 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         pp.id,
         NEW.name,
         NEW.title,
@@ -39,7 +39,7 @@ BEGIN
     FROM
         (SELECT 1)
     LEFT JOIN
-        topics pp
+        nodes pp
     ON
         pp.uuid = NEW.parent_uuid
     ;
