@@ -34,14 +34,14 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         p.id,
         NEW.status,
         NEW.rank,
         NEW.def,
         NEW.uuid
     FROM
-        topics p
+        nodes p
     WHERE
         p.uuid = NEW.project_uuid
     ;
