@@ -28,12 +28,12 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        nextval('topics'),
+        nextval('nodes'),
         ts.id,
         NEW.title,
         NEW.uuid
     FROM
-        topics ts
+        nodes ts
     WHERE
         ts.uuid = NEW.task_status_uuid
     ;
