@@ -1,5 +1,5 @@
 CREATE TABLE func_import_new_work(
-    topic_uuid VARCHAR(40) NOT NULL,
+    node_uuid VARCHAR(40) NOT NULL,
     offset INTEGER NOT NULL,
     start INTEGER NOT NULL,
     stop INTEGER NOT NULL,
@@ -16,7 +16,7 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        NEW.topic_uuid,
+        NEW.node_uuid,
         NEW.offset,
         NEW.start,
         NEW.stop,
@@ -27,7 +27,7 @@ BEGIN
     INSERT INTO
         func_new_work(
             change_id,
-            topic_id,
+            node_id,
             offset,
             start,
             stop,
@@ -36,16 +36,16 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        t.id,
+        n.id,
         NEW.offset,
         NEW.start,
         NEW.stop,
         NEW.start_comment,
         NEW.stop_comment
     FROM
-        topics t
+        nodes n
     WHERE
-        t.uuid = NEW.topic_uuid
+        n.uuid = NEW.node_uuid
     ;
 
     SELECT RAISE(IGNORE);
