@@ -32,9 +32,9 @@ BEGIN
         h.id,
         NEW.location
     FROM
-        topics hr
+        nodes hr
     LEFT JOIN
-        topics h
+        nodes h
     ON
         h.uuid = NEW.hub_uuid
     WHERE
