@@ -30,7 +30,7 @@ BEGIN
         NEW.name,
         NEW.title
     FROM
-        topics h
+        nodes h
     WHERE
         h.uuid = NEW.uuid
     ;
