@@ -38,13 +38,13 @@ BEGIN
         con.id,
         dcm.id
     FROM
-        topics i
+        nodes i
     LEFT JOIN
-        topics con
+        nodes con
     ON
         con.uuid = NEW.contact_uuid
     LEFT JOIN
-        topics dcm
+        nodes dcm
     ON
         dcm.uuid = NEW.default_contact_method_uuid
     WHERE
