@@ -36,7 +36,7 @@ BEGIN
         NEW.rank,
         NEW.def
     FROM
-        topics AS issue_status
+        nodes AS issue_status
     INNER JOIN
         changes c
     ON
