@@ -31,9 +31,9 @@ BEGIN
         s.id,
         NEW.title
     FROM
-        topics i
+        nodes i
     LEFT JOIN
-        topics s
+        nodes s
     ON
         s.uuid = NEW.issue_status_uuid
     WHERE
