@@ -36,7 +36,7 @@ BEGIN
         NEW.rank,
         NEW.def
     FROM
-        topics AS project_status
+        nodes AS project_status
     INNER JOIN
         changes c
     ON
