@@ -36,7 +36,7 @@ BEGIN
         NEW.rank,
         NEW.def
     FROM
-        topics AS task_status
+        nodes AS task_status
     INNER JOIN
         changes c
     ON
