@@ -27,17 +27,17 @@ BEGIN
         )
     SELECT
         currval('changes'),
-        t.id,
+        n.id,
         s.id,
         NEW.title
     FROM
-        topics t
+        nodes n
     LEFT JOIN
-        topics s
+        nodes s
     ON
         s.uuid = NEW.task_status_uuid
     WHERE
-        t.uuid = NEW.uuid
+        n.uuid = NEW.uuid
     ;
 
     SELECT RAISE(IGNORE);
