@@ -37,7 +37,7 @@ BEGIN
                     '  location: ' || NEW.location || x'0A'
                 END
             FROM
-                topics h
+                nodes h
             WHERE
                 h.id = NEW.hub_id
         )
@@ -45,7 +45,7 @@ BEGIN
         id = NEW.change_id
     ;
 
-    INSERT INTO func_new_topic(
+    INSERT INTO func_new_node(
         id,
         change_id,
         parent_id,
