@@ -61,7 +61,7 @@ BEGIN
                         '  mvalue: ' || NEW.mvalue || x'0A'
                     END
             FROM
-                topics i
+                nodes i
             WHERE
                 i.id = NEW.identity_id
         )
@@ -71,7 +71,7 @@ BEGIN
 
 
     INSERT INTO
-        func_new_topic(
+        func_new_node(
             change_id,
             id,
             parent_id,
@@ -115,10 +115,10 @@ BEGIN
     );
 
     INSERT INTO
-        topic_deltas(
+        node_deltas(
             id,
             change_id,
-            topic_id,
+            node_id,
             name
         )
     VALUES(
