@@ -50,11 +50,11 @@ BEGIN
             FROM
                 (SELECT 1)
             LEFT JOIN
-                topics c
+                nodes c
             ON
                 c.id = NEW.contact_id
             LEFT JOIN
-                topics dcm
+                nodes dcm
             ON
                 dcm.id = NEW.default_contact_method_id
         )
@@ -62,7 +62,7 @@ BEGIN
         id = NEW.change_id
     ;
 
-    INSERT INTO func_new_topic(
+    INSERT INTO func_new_node(
         id,
         change_id,
         name,
@@ -103,10 +103,10 @@ BEGIN
     );
 
     INSERT INTO
-        topic_deltas(
+        node_deltas(
             id,
             change_id,
-            topic_id
+            node_id
         )
     VALUES(
         currval('deltas'),
