@@ -44,7 +44,7 @@ BEGIN
                 END
 
             FROM
-                topics p
+                nodes p
             WHERE
                 p.id = NEW.project_id
         )
@@ -52,7 +52,7 @@ BEGIN
         id = NEW.change_id
     ;
 
-    INSERT INTO func_new_topic(
+    INSERT INTO func_new_node(
         id,
         parent_id,
         change_id,
@@ -97,10 +97,10 @@ BEGIN
     );
 
     INSERT INTO
-        topic_deltas(
+        node_deltas(
             id,
             change_id,
-            topic_id,
+            node_id,
             name
         )
     VALUES(
