@@ -59,9 +59,9 @@ BEGIN
                         '  title: ' || NEW.title || x'0A'
                     END
             FROM
-                topics s
+                nodes s
             LEFT JOIN
-                topics src
+                nodes src
             ON
                 src.id = NEW.src_id
             WHERE
@@ -71,7 +71,7 @@ BEGIN
         id = NEW.change_id
     ;
 
-    INSERT INTO func_new_topic(
+    INSERT INTO func_new_node(
         id,
         parent_id,
         change_id,
@@ -124,10 +124,10 @@ BEGIN
     );
 
     INSERT INTO
-        topic_deltas(
+        node_deltas(
             id,
             change_id,
-            topic_id,
+            node_id,
             name
         )
     VALUES(
