@@ -1,8 +1,8 @@
 CREATE TABLE hubs (
     id INTEGER NOT NULL PRIMARY KEY,
     location VARCHAR NOT NULL UNIQUE,
-    hash VARCHAR, -- TODO remove
-    num_changes INTEGER, -- TODO remove
+    hash CHAR(40) DEFAULT 'da39a3ee5e6b4b0d3255bfef95601890afd80709',
+    num_changes INTEGER NOT NULL DEFAULT 0,
     FOREIGN KEY (id) REFERENCES projects(id) ON DELETE CASCADE
 );
 
@@ -43,7 +43,7 @@ BEGIN
     );
 
     DELETE FROM
-        topics
+        nodes
     WHERE
         id = OLD.id
     ;
