@@ -5,7 +5,7 @@ CREATE TABLE issues (
     issue_status_id INTEGER NOT NULL,
     title VARCHAR(1024) NOT NULL DEFAULT '',
     UNIQUE (src_id,project_id),
-    FOREIGN KEY(id) REFERENCES topics(id) ON DELETE CASCADE,
+    FOREIGN KEY(id) REFERENCES nodes(id) ON DELETE CASCADE,
     FOREIGN KEY(src_id) REFERENCES issues(id) ON DELETE CASCADE,
     FOREIGN KEY(project_id,issue_status_id)
         REFERENCES issue_status(project_id,id)
@@ -53,7 +53,7 @@ BEGIN
     );
 
     DELETE FROM
-        topics
+        nodes
     WHERE
         id = OLD.id
     ;
