@@ -14,7 +14,7 @@ BEGIN
     );
 
     DELETE FROM
-        topics
+        nodes
     WHERE
         id = OLD.id
     ;
