@@ -3,7 +3,7 @@ CREATE TABLE tasks (
     change_id INTEGER NOT NULL,
     task_status_id INTEGER NOT NULL,
     title VARCHAR(1024) NOT NULL DEFAULT '',
-    FOREIGN KEY(id) REFERENCES topics(id) ON DELETE CASCADE,
+    FOREIGN KEY(id) REFERENCES nodes(id) ON DELETE CASCADE,
     FOREIGN KEY(change_id) REFERENCES changes(id) ON DELETE CASCADE,
     FOREIGN KEY(task_status_id) REFERENCES task_status(id) ON DELETE CASCADE
 );
@@ -28,7 +28,7 @@ BEGIN
     );
 
     DELETE FROM
-        topics
+        nodes
     WHERE
         id = OLD.id
     ;
