@@ -1,7 +1,7 @@
 CREATE TABLE work_deltas(
     id INTEGER NOT NULL PRIMARY KEY,
     change_id INTEGER NOT NULL,
-    topic_id INTEGER NOT NULL,
+    node_id INTEGER NOT NULL,
     offset INTEGER NOT NULL,
     start INTEGER NOT NULL,
     stop INTEGER NOT NULL,
@@ -11,7 +11,7 @@ CREATE TABLE work_deltas(
     stop_comment TEXT,
     FOREIGN KEY(id) REFERENCES deltas(id) ON DELETE CASCADE,
     FOREIGN KEY(change_id) REFERENCES changes(id) ON DELETE CASCADE,
-    FOREIGN KEY(topic_id) REFERENCES topics(id) ON DELETE CASCADE,
+    FOREIGN KEY(node_id) REFERENCES nodes(id) ON DELETE CASCADE,
     CONSTRAINT start_stop_order CHECK(stop >= start),
     CONSTRAINT offset_check CHECK(offset BETWEEN -64800 AND 64800)
 );
